@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -37,7 +37,7 @@ import logging
 import logging.config
 
 __prog__ = "pyformex"
-__version__ = "2.4"
+__version__ = "2.5"
 __revision__ = __version__
 __branch__ = "master"
 Copyright = 'Copyright (C) 2004-2021 Benedict Verhegghe'
@@ -304,7 +304,7 @@ class options:
     debuglevel = 0  # Make sure we can use
     verbose = 1   # Make sure we can use
     uselib = False  # initial default to keep sphinx happy
-    pathlib = False  # initial default to keep sphinx happy
+#    pathlib = False  # initial default to keep sphinx happy
 
 
 # Are we importing from Sphinx doc generator?
@@ -336,19 +336,19 @@ def busy(state=True):
 
 
 ######################################################################
-###  DEBUG levels
+###  DEBUG items
 ################################
 
 
-class DebugLevels(object):
+class DEBUG(object):
 
-    """A class with debug levels.
+    """A class with debug items.
 
-    This class holds the defined debug levels as attributes.
-    Each debug level is a binary value with a single bit set (a power of 2).
-    Debug levels can be combined with & (AND), | (OR) and ^ (XOR).
-    Two extra values are defined: None swtiches off all debugging, All
-    activates all debug levels.
+    This class holds the defined debug items as attributes.
+    Each debug topic is a binary value with a single bit set (a power of 2).
+    Debug items can be combined with & (AND), | (OR) and ^ (XOR).
+    Two extra values are defined: NONE switches off all debugging, ALL
+    activates all debug items.
 
     """
     ALL = -1
@@ -359,22 +359,13 @@ class DebugLevels(object):
      ) = [2 ** i for i in range(29)]
 
 
-try:
-    # Python2 stores the local variable 'i'
-    delattr(DebugLevels, 'i')
-except Exception:
-    # Python3 seems not to store it
-    pass
-
-DEBUG = DebugLevels
-
-
 def debugItems():
     """Return all existing debug items"""
-    return [k.lower() for k in dir(DebugLevels) if not k.startswith('_')]
+    return [k.lower() for k in dir(DEBUG) if not k.startswith('_')]
 
 
 def debugLevel(sl):
+    """Return the combined debug level for a list of debug items"""
     lev = 0
     for l in sl:
         try:
@@ -428,10 +419,10 @@ if len(sys.argv) > 1 and sys.argv[1].endswith('pyformex'):
     if not parseOptions(sys.argv[2:]):
         sys.exit(1)
 
-if options.pathlib:
-    from pathlib import Path
-else:
-    from pyformex.path import Path
+# if options.pathlib:
+#     from pathlib import Path
+# else:
+from pyformex.path import Path
 
 # Placeholder for excutable, if pyformex: filled in by startup.py
 executable = Path(sys.executable)
