@@ -6,7 +6,7 @@ from pyformex import script
 from pyformex.gui.draw import scriptRelease, askItems, _I
 
 
-def runAll(self, startfrom='A', stopat='[', count=-1, recursive=True,
+def runAll(startfrom='A', stopat='[', count=-1, recursive=True,
            timeout=1.0, pause=1.0, shuffle=False):
     """Run all apps with a name in the range [startfrom,stopat[.
 
@@ -20,11 +20,11 @@ def runAll(self, startfrom='A', stopat='[', count=-1, recursive=True,
     from pyformex.gui.draw import layout, reset, sleep
     from pyformex.gui import widgets
 
-    if self.mode != 'app':
-        print("I can only do this in 'App' mode, not 'Script' mode")
-        return
+    # Get the Apps Examples menu
+    appmenu = pf.GUI.menu['App']
+    examples = appmenu['Examples']['Byname']
 
-    files = self.listApps()
+    files = examples.listApps()
     print(f"Total number of apps: {len(files)}")
     print(f"Start from {startfrom}; stop at {stopat}; count {count}; random {shuffle}")
     if startfrom is not None:
@@ -52,7 +52,7 @@ def runAll(self, startfrom='A', stopat='[', count=-1, recursive=True,
                 reset()
                 pf.PF.clear()
                 print("Running app '%s'" % f)
-                #self.runApp(f)
+                #examples.runApp(f)
                 script.runAny(f, wait=True)
                 script.breakpt(msg="Breakpoint from runall")
                 if script.exitrequested:
@@ -66,22 +66,20 @@ def runAll(self, startfrom='A', stopat='[', count=-1, recursive=True,
 
 
 def run():
+    # Save the name of the current app
     my_name = pf.GUI.curfile.bg.buttons()[1].text()
-    appmenu = pf.GUI.menu['App']
-    ex_menu = appmenu['Examples']['Byname']
     res = askItems([
         _I('startfrom', 'A', text='Start from'),
         _I('stopat', '[', text='Stop at'),
         _I('count', -1, text='Count'),
-        _I('shuffle', False, text='Play in random order'),
+        _I('shuffle', True, text='Play in random order'),
         _I('timeout', 0.5, text='Timeout dialogs after (secs)'),
         _I('pause', 1.0, text='Time to pause after each app'),
     ])
     if res:
         print(res)
         scriptRelease('__auto/app__')
-        runAll(ex_menu, **res)
-#        ex_menu.runAll(**res)
+        runAll(**res)
     pf.GUI.setcurfile(my_name)
 
 
