@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -53,7 +53,7 @@ from pyformex import Path
 
 
 def formatDict(d):
-    """Format a dict in Python source representation.
+    """Format a Config in Python source representation.
 
     Each (key,value) pair is formatted on a line of the form::
 
@@ -458,7 +458,7 @@ class Config(Dict):
         be read back through Python to recreate the Config data. Usually
         this is done with the Config.read() method.
         """
-        from pyformex.utils import formatDict
+        #from pyformex.utils import formatDict
         s = ''
         for k, v in self.items():
             if not isinstance(v, Dict):
