@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -94,7 +94,7 @@ def run():
 
     # Create the stiffness and mass matrix
     K, M = createBeam(lt, nel, addbc=True)
-    # Compute the eigenfrquencies and modes
+    # Compute the eigenfrequencies and modes
     f, v = eigen(K, M, neig, method='subspace')
 
     # Compute the theoretical eigenfrequencies (for comparison)
@@ -105,7 +105,8 @@ def run():
     separate = True
 
     if separate:
-        layout(neig)
+        ncol = int(np.ceil(np.sqrt(neig)))
+        layout(neig,ncol)
 
     for i in range(neig):
         # split deflections and rotations
