@@ -1,11 +1,11 @@
 ##  You should have received a copy of the GNU General Public License
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -43,46 +43,34 @@ def run():
     flat()
     nx, ny = 1, 1
     F = Formex('4:0123').replicm((nx, ny)).centered()
-    G = F.scale(0.8)
+    G = F.scale((0.99, 0.6, 0))
     F1 = F.trl(0, 1.2)
     G1 = G.trl(0, 1.2)
     F.attrib(color = [[(1., 0, 0), (0, 1, 0), (0, 0, 1), (1, 0, 1)]])
-    F1.attrib(color = [[(1, 0, 0, 0.0), (0, 1, 0, 1), (0, 0, 1, 1), (1, 0, 1, 0)]])
-    FA = draw(F)
-    FB = draw(F1)
+    F1.attrib(color = [[(1, 0, 0, 0.0), (0, 1, 0, 1.0), (0, 0, 1, 1.0), (1, 0, 1, 0)]])
+    FA = draw(F, ontop=True)
+    FB = draw(F1, ontop=True)
     draw(G)
     draw(G1)
     print("Colors of the left square:")
     print(FA.color)
     print("Colors of the right square:")
     print(FB.color)
-    if pf.options.shader == 'alpha':
-         showInfo("""..
+    showInfo("""..
 
-These two colored squares were drawn with RGBA color mode using the alpha
-shader. The RGB components are the same for both squares. The squares hide
-a smaller black square.
+These two colored squares were drawn with RGBA color mode. The RGB
+components are the same for both squares. The squares hide a black
+rectangle.
 
 For the left square only RGB components were given, without A value:
-the default 0.5 is then used for all points.
+the default 0.5 is then used for all points, making the transparency
+uniform over the square.
 For the right square the value of A was set to 0.0 at the left corners
 and to 1.0 at the right corners, making the transparency
-range from full to minimal over the square.
-
-To see the effect, transparency needs to be switched on. I will do that
-when you push the OK button.
-""")
-         transparent(True)
-    else:
-         showInfo("""..
-
-The effect of the RGBA color mode can currently only be visualized
-when using the alpha shader. Start pyFormex with the command::
-
-  pyformex --shader=alpha
-
-""")
+range horizontally over the square from fully transparent to opaque.
 
+To see the effect, click the 'Toggle Transparent Mode' button.
+""", caption='Example info')
 
 
 if __name__ == '__draw__':
