@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -33,6 +33,7 @@ _topics = ['FEA']
 _techniques = ['dialog', 'color']
 
 import pyformex as pf
+from pyformex import colors
 from pyformex.gui.draw import *
 from pyformex.gui.colorscale import ColorScale, Palette
 from pyformex.opengl.decors import ColorLegend
@@ -106,7 +107,7 @@ def show():
         minexp = None
 
     if custom:
-        palet = tuple(GLcolor(i) for i in (mincol, medcol, maxcol))
+        palet = tuple(colors.GLcolor(i) for i in (mincol, medcol, maxcol))
         if paltype == '2-color':
             palet = (palet[0], None, palet[2])
 
@@ -121,7 +122,7 @@ def show():
         x = 100
 
     # ok, now draw it
-    drawColorScale(palet, minval, maxval, medval, maxexp, minexp, ncolors, dec, scale, ngrid, linewidth, nlabel, lefttext, textsize, GLcolor(textcolor), x, y, w, h)
+    drawColorScale(palet, minval, maxval, medval, maxexp, minexp, ncolors, dec, scale, ngrid, linewidth, nlabel, lefttext, textsize, colors.GLcolor(textcolor), x, y, w, h)
 
 
 def drawColorScale(palet, minval, maxval, medval, maxexp, minexp, ncolors, dec, scale, ngrid, linewidth, nlabel, lefttext, textsize, textcolor, x, y, w, h):
