@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -32,7 +32,7 @@ _topics = ['surface']
 _techniques = ['color']
 
 from pyformex.gui.draw import *
-from pyformex.opengl.drawable import GeomActor
+from pyformex.opengl.actors import Actor
 
 
 def run():
@@ -52,14 +52,15 @@ def run():
     i=0
     for shape in Shapes:
         F = Formex(shape).replicm((4, 2))
-        color3 = resize(color2, F.shape)  # full color
+        color3 = resize(color2, F.shape[:2])  # full color
         for c in [color0, color1, color2, color3]:
             for mode in Rendermode:
                 clear()
                 renderMode(mode)
-                FA = GeomActor(F, color=c)
+                #### draw(F,color=c) does not work for some modes!!
+                FA = Actor(F, color=c)
                 drawActor(FA)
-                ### For some modes, draw(F,color=c) does not work!!
+                #### TODO: test if this is still the case
                 zoomAll()
                 for light in Lights:
                     lights(light)
