@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,7 +27,7 @@
 Example demonstrating the components of input dialogs.
 """
 
-_status = 'failed'
+_status = 'checked'
 _level = 'normal'
 _topics = []
 _techniques = ['dialog']
@@ -101,11 +101,16 @@ input_special = [
     ]
 
 input_tabgroup = [
-    _I('enable1', False, text="Enable group 1"),
-    _G('group1', input_text[1:4], text="Text input group"),
-    _I('enable2', False, text="Enable group 2"),
-    _G('group2', input_select_1[:3], text="Select input group"),
-    _G('group3', input_special[:3], text="Special input group", check=True),
+    _I('enable1', False, text="Enable group 1",
+       tooltip = "Check the box to enable group 1"),
+    _G('group1', input_text[1:4], text="Text input group",
+       tooltip='This is the header of group 1'),
+    _I('enable2', False, text="Enable group 2",
+       tooltip = "Check the box to enable group 2"),
+    _G('group2', input_select_1[:3], text="Select input group",
+       tooltip="This is the header of group 2"),
+    _G('group3', input_special[:3], text="Special input group", check=True,
+       tooltip="Group 3 has a checkbox to enable/disable the group"),
     ]
 
 input_data = [
@@ -118,7 +123,7 @@ input_data = [
 
 input_enablers = [
     ('tabgroup/enable1', True, 'tabgroup/group1'), # 'tabgroup/group2/sel/radio'),
-    ('tabgroup/enable2', True, 'tabgroup/group2', 'tabgroup/group3', 'tabgroup/group1/string'),
+    ('tabgroup/enable2', True, 'tabgroup/group2', 'tabgroup/group1/string'),
     ]
 
 
