@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,7 +28,6 @@ This example illustrates the creation of NurbsCurves interpolating or
 approximating a given point set.
 """
 
-
 _status = 'checked'
 _level = 'advanced'
 _topics = ['geometry', 'curve']
@@ -40,7 +39,6 @@ from pyformex.plugins.curve import *
 from pyformex.plugins.nurbs import *
 
 
-
 point_sets = {
 #    'pt_9.1': [
 #        ( 3.5,),
@@ -147,6 +145,7 @@ def showAll():
 
 
 def timeOut():
+    print(f"TIMEOUT CALLED")
     try:
         showAll()
         wait()
