@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,14 +28,11 @@ This example illustrates the use of the mesh_ext.rectangular function
 and the use of seeds in generating Meshes.
 
 """
-
-
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry', 'mesh']
 _techniques = ['rectangular', 'seed', 'layout']
 
-
 from pyformex.gui.draw import *
 from pyformex.mesh import rectangle
 from pyformex.gui.menus.Viewport import clearAll
@@ -49,7 +46,6 @@ def run():
     clearAll()
     smoothwire()
     fgcolor(red)
-    print(pf.canvas.settings)
     layout(6, 3)
 
     # Viewports are not correctly initialized!
