@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -92,7 +92,7 @@ def run():
     viewer = ImageView(dfilename, maxheight=200)
 
     res = askItems([
-        _I('filename', dfilename, text='Image file', itemtype='filename', filter='img', exist=True, preview=viewer),
+        _I('filename', dfilename, text='Image file', itemtype='filename', filter='img', mode='exist', preview=viewer),
         viewer,
         _I('px', 4, text='Number of patches in x-direction'),
         _I('py', 6, text='Number of patches in y-direction'),
