@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -33,6 +33,7 @@ _topics = ['geometry', 'curve', 'mesh']
 _techniques = ['sweep', 'spiral']
 
 import re
+import random
 from collections import OrderedDict
 
 from pyformex.gui.draw import *
@@ -68,7 +69,8 @@ cross_sections.update({
     'solid_triangle': '3:012',
     'swastika3': '3:012023034041',
     })
-
+cross_choices = list(cross_sections.keys())
+random.shuffle(cross_choices)
 
 dialog_items = [
     _I('nmod', 100, text='Number of cells along spiral'),
@@ -79,7 +81,7 @@ dialog_items = [
     _I('spread', False, text='Spread points evenly along spiral'),
     _I('nwires', 1, text='Number of spirals'),
     _G('sweep', text='Sweep Data', check=True, items= [
-        _I('cross_section', 'cross', choices=listcross_sections.keys(),
+        _I('cross_section', choices=cross_choices,
             text='Shape of cross section'),
         _I('cross_rotate', 0.,
             text='Cross section rotation angle before sweeping'),
