@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -53,7 +53,7 @@ def run():
     fn = getcfg('datadir') / 'world.jpg'
 
     res = askItems([
-        _I('fn', fn, itemtype='file', filter='img', exist=True, text=''),
+        _I('fn', fn, itemtype='file', filter='img', mode='exist', text=''),
         _I('part', itemtype='radio', choices=["Plane", "Half Sphere", "Full Sphere"], text='Show image on'),
         ])
     if not res:
@@ -68,7 +68,6 @@ def run():
         return
 
     nx, ny = im.width(), im.height()
-    #nx,ny = 200,200
 
     # Create the colors
     color, colormap = qimage2glcolor(im.scaled(nx, ny))
