@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -254,7 +254,7 @@ def readPLY(filename, mplex=None):
     >>> from .filewrite import writePLY
     >>> f = Path('test_filewrite.ply')
     >>> M = Mesh(eltype='quad4')
-    >>> writePLY(f, M)
+    >>> writePLY(f, M.coords, {4:M.elems})
     >>> coords, elems = readPLY(f)
     >>> print(coords)
     [[ 0.  0.  0.]
@@ -273,9 +273,8 @@ def readPLY(filename, mplex=None):
 
     filename = Path(filename)
     pf.verbose(1, f"Read PLY file {filename.absolute()}")
-
-    with utils.File(filename, 'r') as fil:
-        ply_data = PlyData.read(filename)
+    with utils.File(filename, 'rb') as fil:
+        ply_data = PlyData.read(fil)
     vertices = ply_data['vertex']
     faces = ply_data['face']
     # Point coordinates
@@ -486,8 +485,8 @@ def read_stl_bin(fil):
     normals = Coords(x[:, 0])
     coords = Coords(x[:, 1:])
     if color is not None:
-        from pyformex.opengl.colors import GLcolor
-        color = GLcolor(color[:3])
+        from pyformex import colors
+        color = colors.GLcolor(color[:3])
     return coords, normals, color
 
 
