@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,16 +28,21 @@ This module defines both the basic routines to write geometrical data
 to a file and the specialized exporters to write files in a number of
 well known standardized formats.
 
-The basic routines are very versatile as well as optimizedand allow to
+Most of the exporters support transparent compression of the output files
+by just specifying a file name that ends in '.gz' or '.bz2'.
+
+The basic routines are very versatile as well as optimized and allow to
 easily create new exporters for other formats.
 """
 
 import sys
+import datetime
 
 import numpy as np
 
 import pyformex as pf
 from pyformex.path import Path
+from pyformex.coords import Coords
 from pyformex.formex import Formex
 from pyformex.mesh import Mesh    # noqa: F401    (used in doctests)
 from pyformex import arraytools as at
@@ -57,19 +62,47 @@ def writePGF(filename, objects, sep=' ', mode='w', shortlines=False,
     The format is portable over different pyFormex versions and
     even to other software.
 
-    - `filename`: the name of the file to be written. If it ends with '.gz'
-      or '.bz2', the file will be compressed with gzip or bzip2, respectively.
-    - `objects`: a list or a dictionary. If it is a dictionary,
-      the objects will be saved with the key values as there names.
-      Objects that can not be exported to a Geometry File will be
-      silently ignored.
-    - `mode`: can be set to 'a' to append to an existing file.
-    - `sep`: the string used to separate data. If set to an empty
-      string, the data will be written in binary format and the resulting file
-      will be smaller but less portable.
-    - `kargs`: more arguments are passed to :meth:`geomfile.GeometryFile.write`.
+    Parameters
+    ----------
+    filename: :term:`path_like`
+        The name of the file to be written. Usually this has a suffix '.pgf'.
+        If a '.gz' or '.bz2' is added, the file will be compressed with gzip
+        or bzip2, respectively.
+    objects: object | list | dict
+        One or more objects to be saved on the file.
+        If it is a dictionary, the keys are saved in the file as the names
+        of the objects.
+        Objects that can not be exported to a pyFormex Geometry File are
+        silently ignored.
+    mode: 'w' | 'a'
+        The mode in which to open the file. The default 'w' will overwrite
+        an existing file. Use 'a' to append to an existing file.
+    sep: str
+        The string used to separate data. If set to an empty string, the
+        data will be written in binary format and the resulting file
+        will be smaller, but less portable.
+    **kargs:
+        Extra keyword arguments are passed to
+        :meth:`~geomfile.GeometryFile.write`.
 
-    Returns the number of objects written to the file.
+    Returns
+    -------
+    int:
+        The number of objects that were written to the file.
+
+    Examples
+    --------
+    >>> f = Path('test_filewrite.pgf')
+    >>> M = Mesh(eltype='quad4').convert('tri3-u')
+    >>> writePGF(f, M)
+    1
+    >>> print(f.read_text())
+    # pyFormex Geometry File (http://pyformex.org) version='2.1'; sep=' '
+    # objtype='Mesh'; ncoords=4; nelems=2; nplex=3; props=False; normals=False; color=None; sep=' '; name='test_filewrite-0'; eltype='tri3'
+    0.0 0.0 0.0 1.0 0.0 0.0 1.0 1.0 0.0 0.0 1.0 0.0
+    0 1 2 2 3 0
+    <BLANKLINE>
+    >>> f.remove()
     """
     from pyformex import geomfile
     pf.debug(f"WriteGeomFile filename{filename}; sep='{sep}'; "
@@ -137,7 +170,7 @@ def writeOBJ(fn, mesh, name=None):
     ----------
     fn: :term:`path_like`
         The output file name, commonly having a suffix '.obj'.
-    mesh: Mesh
+    mesh: :class:`Mesh`
         The Mesh to write to the file.
     name: str, optional
         Name of the Mesh to be written into the file. If not provided None
@@ -187,27 +220,40 @@ def writeOBJ(fn, mesh, name=None):
     pf.verbose(2, f"File size: {fn.size()} bytes")
 
 
-def writePLY(fn, mesh, comment=None, color_table=None, binary=False):
-    """Write a mesh to a file in PLY format.
+def writePLY(fn, coords, faces=None, *, edges=False, comment=None,
+             vcolor=None, fcolor=None, ecolor=None,
+             binary=False):
+    """Write polygons to a file in PLY format.
 
     Parameters
     ----------
     fn: :term:`path_like`
         The output file name, commonly having a suffix '.ply'.
-    mesh: Mesh
-        The Mesh to write to the file.
+        If the name ends in '.gz. or '.bz2', the file will tranasparently
+        be compressed.
+    coords: :term:`coords_like` | :class:`Mesh`
+        A float array (ncoords, 3) with the coordinates of all vertices.
+        As a convenience, if a :class:`Mesh` is specified, the coords and faces
+        arguments are taken from the :attr:`Mesh.coords` and :`Mesh.elems`
+        attributes.
+    faces: dict
+        A dict where the keys are plexitudes (<= mplex) and the values are
+        the Connectivity tables of all the polygons of the plexitude.
+        This should not be provided if a Mesh was given as the coords argument.
     comment: str, optional
         An extra comment to add in the file header.
+    binary: bool
+        If True, a binary file is written. The default is ascii.
 
     Notes
     -----
-    See `<https://en.wikipedia.org/wiki/PLY_(file_format)>`_).
+    For PLY format, see `<https://en.wikipedia.org/wiki/PLY_(file_format)>`_).
 
     Examples
     --------
     >>> f = Path('test_filewrite.ply')
     >>> M = Mesh(eltype='quad4').convert('tri3-u')
-    >>> writePLY(f, M, comment='This is a test')
+    >>> writePLY(f, M.coords, {3:M.elems}, comment='This is a test')
     >>> print(f.read_text())
     ply
     format ascii 1.0
@@ -218,7 +264,7 @@ def writePLY(fn, mesh, comment=None, color_table=None, binary=False):
     property float y
     property float z
     element face 2
-    property list uchar int vertex_indices
+    property list int int vertex_indices
     end_header
     0.0 0.0 0.0
     1.0 0.0 0.0
@@ -229,68 +275,87 @@ def writePLY(fn, mesh, comment=None, color_table=None, binary=False):
     <BLANKLINE>
     >>> f.remove()
     """
+    def int_color(color):
+         return (255*vcolor).astype(Int).clip(0,255)
+
+    if isinstance(coords, Mesh):
+        coords, faces = coords.coords, {coords.nplex():coords.elems}
+    else:
+        coords = Coords(coords)
+    if not isinstance(faces, dict):
+        raise ValueError("writePLY: faces should be a dict")
+    for nplex in faces:
+        if faces[nplex].shape[1] != nplex:
+            raise ValueError(f"faces[{nplex}]: plexitude does not match the key")
+
     fn = Path(fn)
     pf.verbose(1, f"Write PLY file {fn.absolute()}")
-    binary = False    # currently only ascii
-    color_table = None   # broken anyway
-    coords = mesh.coords
-    elems = mesh.elems
-    with utils.File(fn, 'w') as fil:
+    now = datetime.datetime.now().isoformat()
+    if binary:
+        fmt = f"binary_{sys.byteorder}_endian 1.0"
+    else:
+        fmt = "ascii 1.0"
+    header = [ "ply",
+               f"format {fmt}",
+               f"comment .ply file written by {pf.Version()} on {now}"
+    ]
+    if comment is not None:
+        header.append(f"comment {comment}")
+    cprop_type = 'uchar'
+    color_type = [f"property {cprop_type} {color}"
+                  for color in ['red', 'green', 'blue']]
+    # vertices
+    ncoords = coords.shape[0]
+    header.extend([f"element vertex {ncoords}",
+                   "property float x",
+                   "property float y",
+                   "property float z",
+    ])
+    if vcolor:
+        header.extend(color_type)
+        vcolor = int_color(vcolor)
+    # faces
+    nelems = sum([faces[nplex].shape[0] for nplex in faces])
+    header.extend([f"element face {nelems}",
+                   "property list int int vertex_indices",
+    ])
+    if fcolor:
+        header.extend(color_type)
+        fcolor = int_color(fcolor)
+    # edges
+    if edges:
+        edges = [Mesh(coords, faces[nplex]).getEdges() for nplex in faces]
+        edges = np.concatenate(edges)
+        nedges = edges.shape[0]
+        header.append("element edge {nedges}")
+        header.extend(["property int vertex{%i}" for i in (1,2)])
+        if ecolor:
+            header.append(color_type)
+            ecolor = int_color(ecolor)
+    # end header
+    header.append("end_header\n")
+    header = '\n'.join(header)
+    #print(header)
+    with utils.File(fn, 'wb') as fil:
+        fil.write(header.encode('utf-8'))
+        pf.verbose(2, f"Write {ncoords} vertices")
         if binary:
-            fmt = 'binary_' + sys.byteorder + '_endian 1.0'
+            print(coords.shape)
+            print(coords.dtype)
+            fil.write(coords.tobytes())
         else:
-            fmt = 'ascii 1.0'
-
-        fil.write(f"""ply
-format {fmt}
-comment .ply file written by {pf.Version()}
-""")
-        if comment is not None:
-            fil.write("comment %s\n" % str(comment))
-        nplex = mesh.nplex()
-        el_type = {2: 'edge'}.get(nplex, 'face')
-        vcol_type = ecol_type = ''
-        if el_type == 'edge':
-            eprop_type = "property int vertex1\nproperty int vertex2"
-        else:
-            eprop_type = "property list uchar int vertex_indices"
-        if color_table is not None:
-            # color_table currently is a list of 2 elements. The first entry
-            # is a string that can assume 2 values 'v' or 'e', to indicate
-            # whether the color table represents nodal or element
-            # values. The second entry is an array of shape (ncoords,3) or
-            # (nelems,3) of interger RGB values between 0 and 255. If RGB
-            # values are passed as float between 0 and 1, they will be
-            # converted to RGB integers.
-            color_location, color_table = color_table
-            if not(np.issubclass_(color_table.dtype.type, np.integer)):
-                color_table = (255*color_table.clip(0., 1.)).astype(np.integer)
-            # float can be added but they are implemented yet
-            cprop_type = {}.get(color_table.dtype, 'uchar')
-            cprop_types = f"""\
-property {cprop_type} red
-property {cprop_type} green
-property {cprop_type} blue
-"""
-            if color_location == 'v':
-                vcol_type = cprop_types
-                coords = np.hstack([coords, color_table])
-            if color_location == 'e':
-                ecol_type = cprop_types
-                elems = np.hstack([elems, color_table])
-        fil.write(f"""\
-element vertex {mesh.ncoords()}
-property float x
-property float y
-property float z
-{vcol_type}element {el_type} {mesh.nelems()}
-{eprop_type}{ecol_type}
-end_header
-""")
-        writeData(fil, coords, fmt='%s', sep=' ')
-        nelems = np.full_like(elems[:, :1], mesh.elems.shape[1])
-        elemdata = np.column_stack([nelems, elems])
-        writeData(fil, elemdata, fmt='%i', sep=' ')
+            writeData(fil, coords, fmt='%s', sep=' ')
+        for nplex in faces:
+            elems = faces[nplex]
+            nelems = np.full_like(elems[:, :1], nplex)
+            pf.verbose(2, f"Write {elems.shape[0]} faces of plexitude {nplex}")
+            elemdata = np.column_stack([nelems, elems])
+            if binary:
+                print(elemdata.shape)
+                print(elemdata.dtype)
+                fil.write(elemdata.tobytes())
+            else:
+                writeData(fil, elemdata, fmt='%i', sep=' ')
     pf.verbose(2, f"File size: {fn.size()} bytes")
 
 
@@ -552,14 +617,12 @@ def writeData(fil, data, fmt=None, sep='', end='\n'):
         for float data.
     sep: str, optional
         A string to be used as separator between single items.
-        If an empty string and no `fmt` is provided, the data are written
-        in binary mode. This is the default.
-        For any other string, the data are written in ascii mode with
-        the specified string inserted as separator between any two items.
+        Only used if fmt is provided and the file is written in ascii mode.
     end: str, optional
         A string to be written at the end of the data block (if no `fmt`)
         or at the end of each row (with `fmt`). The default value is a newline
         character.
+        Only used if fmt is provided and the file is written in ascii mode.
 
     Examples
     --------
