@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -44,7 +44,7 @@ of results from Finite Element simulation programs.
 
 """
 
-from pyformex.opengl.colors import *
+from pyformex import colors
 from pyformex.arraytools import stuur
 import numpy as np
 
@@ -53,16 +53,17 @@ Palette = {
     'RAINBOW': ((-2., 0., 2.), (0., 2., 0.), (2., 0., -2.)),
     'IRAINBOW': ((2., 0., -2.), (0., 2., 0.), (-2., 0., 2.)),
     'HOT': ((0., 0., -2), (1., 0., -1), (1., 2., 1.)),
-    'RGB': (red, green, blue),
-    'BGR': (blue, green, red),
-    'RWB': (red, white, blue),
-    'BWR': (blue, white, red),
-    'RWG': (red, white, green),
-    'GWR': (green, white, red),
-    'GWB': (green, white, blue),
-    'BWG': (blue, white, green),
-    'BW': (black, None, white),
-    'WB': (white, grey(0.5), black),    # could be None or grey(0.5)
+    'RGB': (colors.red, colors.green, colors.blue),
+    'BGR': (colors.blue, colors.green, colors.red),
+    'RWB': (colors.red, colors.white, colors.blue),
+    'BWR': (colors.blue, colors.white, colors.red),
+    'RWG': (colors.red, colors.white, colors.green),
+    'GWR': (colors.green, colors.white, colors.red),
+    'GWB': (colors.green, colors.white, colors.blue),
+    'BWG': (colors.blue, colors.white, colors.green),
+    'BW': (colors.black, None, colors.white),
+    'WB': (colors.white, colors.grey(0.5), colors.black),
+            # could be None or grey(0.5)
     # From matplotlib:
     'PLASMA': ((0.050383, 0.029803, 0.527975),
                (0.794549, 0.275770, 0.473117),
