@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -38,19 +38,21 @@ from pyformex import process
 from pyformex import utils
 from pyformex import coords
 from pyformex import Path
+from pyformex import colors
 from pyformex.attributes import Attributes
 from pyformex.formex import Formex, connect
-from pyformex.gui import widgets, QtCore
+from pyformex.gui import dialogs
+from pyformex.gui import widgets
+from pyformex.gui import QtCore
 from pyformex.gui import toolbar
 from pyformex.gui import image
 from pyformex.gui import drawlock
-from pyformex.opengl import colors, actors, decors
+from pyformex.opengl import actors, decors
 
 # Extra things that we want in the scripting language
-from pyformex.gui.widgets import Dialog, _I, _G, _C, _T
 from pyformex.script import *
 from pyformex.lazy import *
-from pyformex.opengl.colors import *
+from pyformex.gui.widgets import Dialog, _I, _C, _G, _T
 from pyformex.gui.toolbar import timeout
 from pyformex.gui import image
 from pyformex.gui import views
@@ -115,17 +117,17 @@ def showMessage(text, actions=['OK'], level='info', modal=True, align='00', **ka
         return w.getResults()
 
 
-def showInfo(text, actions=['OK'], modal=True):
+def showInfo(text, actions=['OK'], modal=True, **kargs):
     """Show an informational message and wait for user acknowledgement."""
-    return showMessage(text, actions, 'info', modal)
+    return showMessage(text, actions, 'info', modal, **kargs)
 
-def warning(text, actions=['OK']):
+def warning(text, actions=['OK'], **kargs):
     """Show a warning message and wait for user acknowledgement."""
-    return showMessage(text, actions, 'warning')
+    return showMessage(text, actions, 'warning', **kargs)
 
-def error(text, actions=['OK']):
+def error(text, actions=['OK'], **kargs):
     """Show an error message and wait for user acknowledgement."""
-    return showMessage(text, actions, 'error')
+    return showMessage(text, actions, 'error', **kargs)
 
 
 def ask(question, choices=None, **kargs):
@@ -379,18 +381,6 @@ def currentDialog():
     """
     return _dialog_widget
 
-# def dialogAccepted():
-#     """Returns True if the last askItems() dialog was accepted."""
-#     return _dialog_result == widgets.ACCEPTED
-
-# def dialogRejected():
-#     """Returns True if the last askItems() dialog was rejected."""
-#     return _dialog_result == widgets.REJECTED
-
-# def dialogTimedOut():
-#     """Returns True if the last askItems() dialog timed out."""
-#     return _dialog_result == widgets.TIMEOUT
-
 
 def selectItems(choices, caption='Select from list', default=[], single=False,
                 check=False, sort=False, **kargs):
@@ -415,60 +405,34 @@ def selectItems(choices, caption='Select from list', default=[], single=False,
      return res
 
 
-def askFile(cur=None, filter='all', exist=True, multi=False, compr=False,
-            change=True, timeout=None, caption=None, sidebar=None, **kargs):
+def askFile(path=None, filter='all', *, mode='file', compr=False,
+            timeout=None, caption=None, sidebar=None, extra=[], **kargs):
     """Ask for one or more files using a customized file dialog.
 
-    This is like :func:`askFileName` but returns a Dict with the full
-    dialog results instead of the filename(s) themselves. This is
-    especially intended for file types that add custom fields to the
-    FileDialog.
+    Shows a modal :class:`FileDialog` and allows the user to select file(s)
+    according to the parameters. See the :class:`FileDialog` for the meaning
+    of the parameters. The timeout parameter is passed to
+    :meth:`FileDialog.getresults`.
 
     Returns
     -------
-    Dict | None
-        A Dict with the results of the file dialog. If the user accepted the
-        selection, the Dict has at least a key 'fn' holding the selected
-        filename(s): a single file name is if `multi` is False, or a list of
-        file names if `multi` is True. If the user canceled the selection
-        process, the Dict is empty.
+    dict
+        A dict with the results of the :class:`FileDialog`. If the user
+        canceled the selection process, the dict is empty.
+        If the user accepted the selection, the dict has at least a key
+        'filename' with the selection: a single Path, except for 'multi'
+        mode, which returns a list of Path.
+        More keys are present if the dialog contains more input items,
+        either specified in the extra argument, or forced by some specific
+        filter.
     """
-    if cur is None:
-        cur = pf.cfg['workdir']
-    cur = Path(cur)
-    if cur.is_dir():
-        fn = ''
-    else:
-        fn = cur.name
-        cur = cur.parent
     if filter == 'pgf':
-        w = widgets.GeometryFileDialog(cur, filter, exist, compr=compr, caption=caption, sidebar=sidebar, **kargs)
+        _Dialog = dialogs.GeometryFileDialog
     else:
-        w = widgets.FileDialog(cur, filter, exist, multi=multi, compr=compr, caption=caption, sidebar=sidebar, **kargs)
-    if fn:
-        w.selectFile(fn)
-    res = w.getResults(timeout)  # results dict
-    _dialog_result = w.result()  # Accepted, rejected or timeout
-    if res:
-        fn = res.fn
-        #print(f"Original: {fn}")
-        if not exist and not multi:
-            # Check and force extension for single new file
-            filtr = w.selectedNameFilter()
-            #print(filtr)
-            okext = utils.fileTypesFromFilter(filtr)
-            #print(f"Selected filter: {w.selectedNameFilter()}")
-            #print(f"Accepted extensions: {okext}")
-            if not ('' in okext or fn.filetype() in okext):
-                res.fn = fn = fn.with_suffix('.'+okext[0])
-            #print(f"Got filename {fn}")
-
-        if fn and change:
-            if multi:
-                cur = fn[0]
-            else:
-                cur = fn
-            chdir(cur.parent)
+        _Dialog = dialogs.FileDialog
+    w = _Dialog(path, filter, mode=mode, compr=compr,
+                caption=caption, sidebar=sidebar, **kargs)
+    res = w.getResults(timeout=timeout)
     pf.GUI.update()
     pf.app.processEvents()
     return res
@@ -492,12 +456,14 @@ def askFilename(*args, **kargs):
         through the :func:`utils.fileDescription` function to create the
         actual filter set. If multiple filters are included, the user can
         switch between them in the dialog.
-    exist: bool
-        If True, the filename must exist. The default (False) will
-        allow a new file to be created or an existing to be used.
-    multi: bool
-        If True, allows the user to pick multiple file names
-        in a single operation.
+    mode: str
+        Determines what can be selected. One of:
+
+        - 'file': select a file (existing or not). This is the default.
+        - 'exist': select an existing file
+        - 'dir': select an existing directory (widget allows to create a new)
+        - 'any': select a file (existing or not) or a directory
+        - 'multi': select multiple existing paths from the same directory
     compr: bool
         If True, the specified filter pattern will be extended with
         the corresponding compressed file types. For example, a filter
@@ -524,9 +490,15 @@ def askFilename(*args, **kargs):
         The selected file Path(s) if the user accepted the dialog, or None
         if the user canceled the dialog.
     """
+    for key in ['exist', 'multi']:
+        if key in kargs:
+            utils.warn('deprecated_filemode')
+            if kargs[key]:
+                kargs['mode'] = key
+            del kargs[key]
     res = askFile(*args, **kargs)
     if res:
-        return res.fn
+        return res['filename']
     else:
         return None
 
@@ -538,12 +510,12 @@ def askNewFilename(cur=None, filter="All files (*.*)", compr=False,
     This is a convenience function for calling askFilename with the
     argument exist=False.
     """
-    return askFilename(cur=cur, filter=filter, exist=False, multi=False,
+    return askFilename(cur=cur, filter=filter, mode='file',
                        compr=compr, timeout=timeout, caption=caption,
                        sidebar=sidebar, **kargs)
 
 
-def askDirname(path=None, change=True, byfile=False, caption=None):
+def askDirname(path=None, change=True, byfile=False, **kargs):
     """Interactively select a directory and change the current workdir.
 
     The user is asked to select a directory through the standard file
@@ -553,30 +525,32 @@ def askDirname(path=None, change=True, byfile=False, caption=None):
     The selected directory becomes the new working directory, unless the
     user canceled the operation, or the change parameter was set to False.
     """
-    if path is None:
-        path = pf.cfg['workdir']
-    path = Path(path)
-    if not path.is_dir():
-        path = path.parent
-    if byfile:
-        dirmode = 'auto'
-    else:
-        dirmode = True
-    fn = widgets.FileDialog(path, '*', dir=dirmode, caption=caption).getFilename()
-    if fn:
-        if not fn.is_dir():
-            fn = fn.parent
+    # if path is None:
+    #     path = pf.cfg['workdir']
+    # path = Path(path)
+    # if not path.is_dir():
+    #     path = path.parent
+    mode = 'any' if byfile else 'dir'
+    w = dialogs.FileDialog(
+        path, filter='*', mode=mode, chdir=None, **kargs)
+    res = w.getResults()
+    if res:
+        dirname = res['filename']
+        if not dirname.is_dir():
+            dirname = dirname.parent
         if change:
-            chdir(fn)
+            chdir(dirname)
+    else:
+        dirname = None
     pf.GUI.update()
     pf.app.processEvents()
-    return fn
+    return dirname
 
 
 def askImageFile(fn=None, compr=False):
     if not fn:
         fn = pf.cfg['pyformexdir']
-    return askFilename(fn, filter=['img', 'all'], multi=False, exist=True)
+    return askFilename(fn, filter=['img', 'all'], mode='exist')
 
 
 def checkWorkdir():
@@ -2139,17 +2113,19 @@ def drawImage3D(image, nx=0, ny=0, pixel='dot'):
     See also :func:`drawImage`.
     """
     from pyformex.plugins.imagearray import qimage2glcolor, resizeImage
-    from pyformex.opengl.colors import GLcolorA
+    from pyformex import colors
 
     with busyCursor():
         # Create the colors
         #print("TYPE %s" % type(image))
         if isinstance(image, np.ndarray):
             # undocumented feature: allow direct draw of 2d array
-            color = GLcolorA(image)
+            color = image
+            if color.dtype.kind == 'i':
+                color = color / 255
             nx, ny = color.shape[:2]
             colortable = None
-            print(color)
+            #print(color)
         else:
             image = resizeImage(image, nx, ny)
             nx, ny = image.width(), image.height()
