@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -39,25 +39,23 @@ from pyformex import software
 
 # If we get here, either PySide2, PySide, PyQt5 or PyQt4 are imported
 # Check for OpenGL
-software.Module.has('pyopengl', fatal=True)
+if not pf.sphinx:
+    if pf.options.mgl:
+        software.Module.has('moderngl', fatal=True)
+    elif not pf.options.gl3:
+        software.Module.has('pyopengl', fatal=True)
 software.Module.has('pil', fatal=True)
 
 from pyformex.gui import (
-    signals, QtCore, QtGui, QtWidgets, QPixmap,
+    signals, QtCore, QtGui, QtWidgets, QPixmap, qtgl,
     menu, appMenu,
     toolbar, viewport, guifunc, draw, widgets, drawlock, views,
     )
 from pyformex.gui.menus import File, Settings, Viewport, Globals
-from pyformex.opengl import canvas
+from pyformex.opengl import canvas_settings
 from pyformex.gui.qtutils import *
 
 
-def hasDRI():
-    """Check whether the OpenGL canvas has DRI enabled."""
-    viewport.setOpenGLFormat()
-    dri = viewport.opengl_format.directRendering()
-    return dri
-
 ################# Message Board ###############
 
 class Board(QtWidgets.QTextEdit):
@@ -502,7 +500,7 @@ class Gui(QtWidgets.QMainWindow):
         self.runallmode = False
 
         # Materials and Lights database
-        self.materials = canvas.createMaterials()
+        self.materials = canvas_settings.createMaterials()
         ## for m in self.materials:
         ##     print self.materials[m]
 
@@ -540,10 +538,19 @@ class Gui(QtWidgets.QMainWindow):
             The dialog with the specified caption, or None if there is no
             such dialog.
         """
+        found = None
+        delete = []
         for d in self.dialogs:
-            if d.windowTitle() == caption:
-                return d
-        return None
+            try:
+                if d.windowTitle() == caption:
+                    found = d
+                    break
+            except RuntimeError:
+                # Window has disappeared
+                delete.append(d)
+        for d in delete:
+            self.dialogs.remove(d)
+        return found
 
 
     def addStatusbarButtons(self, name, actions, **kargs):
@@ -1277,6 +1284,8 @@ def findOldProcesses(max=16):
     running pyFormex GUI processes, if any.
     """
     windowname = pf.Version()
+    if pf.options.gl3:
+        windowname += '--gl3'
     count = 0
     running = []
 
@@ -1388,9 +1397,9 @@ def startGUI(args):
     #
     pf.debug("Arguments left after constructing the QApplication: %s" % args, pf.DEBUG.INFO)
     pf.debug("Arguments left after constructing the QApplication: %s" % '\n'.join(pf.app.arguments()), pf.DEBUG.INFO)
-    #pf.options.debug = 0
-    # As far as I have been testing this, the args passed to the Qt application are
-    # NOT acknowledged and neither are they removed!!
+    # TODO: decide how to use the args or remove this
+    # As far as I have been testing this, the args passed to the Qt application
+    # are NOT acknowledged and neither are they removed!!
 
 
     pf.debug("Setting application attributes", pf.DEBUG.INFO)
@@ -1409,7 +1418,8 @@ def startGUI(args):
     pf.app.lastWindowClosed.connect(pf.app.quit)
 
     # Set OpenGL format and check if we have DRI
-    dri = hasDRI()
+    qtgl.setOpenGLFormat()
+    dri = qtgl.hasDRI()
 
     # Check for existing pyFormex processes
     pf.debug("Checking for running pyFormex", pf.DEBUG.INFO)
@@ -1551,10 +1561,8 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
         pf.GUI.processEvents()
         pf.GUI.viewports.changeLayout(1)
         pf.GUI.viewports.setCurrent(0)
-        #pf.canvas = pf.GUI.viewports.current
         pf.canvas.setRenderMode(pf.cfg['draw/rendermode'])
         draw.reset()
-
         # set canvas background
         # (does not work before a draw.reset, do not know why)
         pf.canvas.setBackground(color=pf.cfg['canvas/bgcolor'],
@@ -1643,6 +1651,15 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
     pf.app_started = True
     pf.GUI.processEvents()
 
+    ##### GUI ready ########
+    if pf.options.runall:
+       from pyformex.appsdir.RunAll import runAll
+       runAll(count=pf.options.runall, shuffle=True)
+       # TODO: should we continue or exit here?
+       pf.GUI.close()
+       pf.app.quit()
+       sys.exit()
+
     # load last project
     #
     #  TODO
@@ -1679,7 +1696,7 @@ def createDatabases():
         }
 
 
-easter_egg='ZnJvbSBkYXRldGltZSBpbXBvcnQgZGF0ZQp0b2RheSA9IGRhdGUudG9kYXkoKQppZiB0b2RheSA8IGRhdGUoMjAxOSw2LDEpIG9yIHRvZGF5ID4gZGF0ZSgyMDE5LDYsMzApOgogICAgZXhpdCgpCmNsZWFyKCkKdGV4dCA9ICdweUZvcm1leCAqMTUgeWVhcnMqIDotKSAnKjMKRiA9IEZvcm1leCgnNDowMTIzJykucmVwbGljKGxlbih0ZXh0KSkKZGEgPSAwLjAwNQpuPTEwMApyID0gbGlzdChyYW5nZShuKSkKRkEgPSBOb25lCmZvciBpIGluIHIgKyByWzo6LTFdOgogICAgYSA9IGkqZGEKICAgIHRvcnNlID0gbGFtYmRhIHgsIHksIHo6IFt4LCBjb3MoYSp4KSp5LXNpbihhKngpKnosIGNvcyhhKngpKnorc2luKGEqeCkqeV0KICAgIEcgPSBGLm1hcCh0b3JzZSkKICAgIEdBID0gZHJhd1RleHQodGV4dCxzaXplPTQwLHBvcz0oMTAsMjAwKSxncmlkPUcpCiAgICB1bmRyYXcoRkEpCiAgICBGQSA9IEdBCiAgICBzbGVlcCgwLjAxKQphdXRvZ2xvYmFscz1Ob25lCg=='
+easter_egg=''
 
 def runGUI():
     """Go into interactive mode"""
@@ -1696,7 +1713,7 @@ def runGUI():
 
     pf.interactive = True
 
-    if pf.cfg['gui/easter_egg'] and True:
+    if easter_egg:
         pf.debug("Show easter egg", pf.DEBUG.INFO)
         try:
             draw.playScript(easter_egg, encoding='egg')
