@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -51,7 +51,6 @@ tool_choices: list of str
     A list of the available tools for saving images.
 """
 
-from OpenGL import GL
 from PIL import Image
 
 import pyformex as pf
@@ -364,7 +363,7 @@ def save_qt(filename, format, quality=-1, canvas=None, size=None, alpha=False):
             # Use direct grabbing from current buffer
             # TODO: We could grab from the OpenGL buffers here!!
             #
-            GL.glFlush()
+            canvas.glFinish()
             pf.debug(f"Saving image from opengl buffer with"
                      f"size {canvas.getSize()}", pf.DEBUG.IMAGE)
             qim = canvas.grabFrameBuffer(withAlpha=alpha)
@@ -392,7 +391,8 @@ def save_qt(filename, format, quality=-1, canvas=None, size=None, alpha=False):
     return sta
 
 
-if gl2ps or pf.sphinx:
+# if we have gl2ps, or when building docs
+if gl2ps or pf.sphinx :
 
     def save_gl2ps(filename, format=None, canvas=None, title='', producer='',
                # viewport=None
@@ -436,6 +436,8 @@ if gl2ps or pf.sphinx:
         save_qt: save the OpenGL rendering as a raster image
         save_window: save the pyFormex window as image file
         """
+        from pyformex.opengl.gl import GL
+
         pf.debug(f"save_window_gl2ps", pf.DEBUG.IMAGE)
         # make sure we have the current content displayed (on top)
         canvas.makeCurrent()
@@ -474,7 +476,7 @@ if gl2ps or pf.sphinx:
                                  gl2ps.GL2PS_BSP_SORT, opts, GL.GL_RGBA,
                                  0, None, 0, 0, 0, bufsize, fp, '')
             canvas.display()
-            GL.glFinish()
+            canvas.glFinish()
             state = gl2ps.gl2psEndPage()
         fp.close()
         return 0
