@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -59,24 +59,20 @@ def saveGeometry():
 def restoreGeometry():
     pf.GUI.restoreGeometry(_geometry)
 
-# This is unneeded as the Qt bug has been resolve
-# def moveCorrect():
-#     pf.GUI.move(*pf.GUI.XPos())
-
 def closeLogFile():
     if draw.logfile:
         draw.logfile.close()
         draw.logfile = None
 
 def openLogFile():
-    fn = draw.askFilename(filter=['*.log', '*'], multi=False)
+    fn = draw.askFilename(filter=['*.log', '*'])
     if fn:
         closeLogFile()
         draw.logfile = open(fn, 'w')
 
 
 def saveBoard():
-    fn = draw.askFilename(filter=['*.txt', '*'], multi=False, exist=False)
+    fn = draw.askFilename(filter=['*.txt', '*'])
     if fn:
         pf.GUI.board.save(fn)
 
@@ -130,7 +126,6 @@ MenuData = (_('&Actions'), [
     (_('&Print Bbox'), draw.printbbox),
     (_('&Print Viewport Settings'), draw.printviewportsettings),
     (_('&Print Window Geometry'), printwindow),
-    # (_('&Correct the Qt Geometry'), moveCorrect),
     (_('&Save Geometry'), saveGeometry),
     (_('&Restore Geometry'), restoreGeometry),
     (_('&Toggle Input Timeout'), toolbar.timeout),
