@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 """Functions from the File menu.
 
 """
-
 from gettext import gettext as _
 
 import pyformex as pf
@@ -33,56 +32,66 @@ from pyformex import utils
 from pyformex import project
 
 from .Settings import updateSettings
-from .. import widgets, dialogs, draw, image
-from ..draw import _I, _G, busyCursor
+from .. import dialogs
+from .. import draw
+from .. import image
+from ..widgets import _I, _G
 
 
 ##################### handle project files ##########################
 
-
 def openProject(fn=None, exist=False, access=['wr', 'rw', 'w', 'r'],
                 default=None):
     """Open a (new or old) Project file.
 
-    A dialog is presented to ask the user for a Project file name and the
-    access modalities. The parameters help in setting sensible defaults
-    for the user and in delimiting his options.
-    Depending on he results of the dialog, either a new project is created or
-    an old one is opened, or nothing is done.
-    If a project is opened, it is returned, else the return value is None.
+    A :class:`~gui.dialogs.ProjectDialog` is shown to ask the user for
+    a Project file name and the access modalities. The parameters are used
+    to set some sensible defaults and delimit the options.
+    Depending on he results of the dialog, either a new project is created
+    or an old one is opened, or nothing is done.
 
-    Parameters:
+    Parameters
+    ----------
+    fn: :term:`path_like`
+        If specified, the Project file dialog is shown with this file
+        initially selected. If not specified, the dialog starts with an
+        empty file name in the current directory.
+    exist: bool
+        If True, only existing Projects can be selected and the function
+        will work like :func:`openExistingProject`. If False (default),
+        the user can create new project files as well as open existing ones.
+    access: list of str
+        A list of :class:`Project` access modes to be presented to
+        the user. The possible access modes are:
 
-    - `fn`: filename: if specified, the Project file dialog will start with
-      the specified file, otherwise it will start in the current directory.
-    - `exist`: boolean: if False (default), the user can create new project
-      files as well as open existing ones. Use exist=True or
-      :func:`openExistingProject` to only accept existing project files.
-    - `access`: a list of :class:`Project` access modes to be presented to
-      the user.
-    - `default`: the access mode that is presented as default to the user.
-      If not specified, the first option of `access` will be the default.
+        - 'wr': open in write mode but read the project first if it exist,
+        - 'rw': like 'wr', but the project must exist (and be read first),
+        - 'w': overwrite the project if it exists,
+        - 'r': open for read only."
+    default: str
+        The access mode that is initially selected in the dialog.
+        If not provided, the first option of ``access`` will be used.
+
+    Returns
+    -------
+    Project | None
+        The opened Project, or None if the user canceled the dialog.
     """
     if isinstance(access, str):
         access = [access]
     cur = fn if fn else '.'
-    res = widgets.ProjectSelection(cur, ['pyf', 'all'], exist=exist, access=access, default=default, convert=True).getResults()
+    res = dialogs.ProjectDialog(
+        cur, ['pyf', 'all'], exist=exist, access=access,
+        default=default, convert=True).getResults()
     if not res:
         return
 
-    fn = res.fn
-    if not fn.endswith('.pyf'):
-        fn += '.pyf'
-    access = res.acc
-    protocol = res.pro
-    compression = res.cpr
-    convert = res.cvt
-    signature = pf.fullVersion()
-
     # OK, we have all data, now create/open the project
-    print("Opening project %s" % fn)
-    with busyCursor():  # loading  may take a while
-        proj = project.Project(fn, access=access, convert=convert, signature=signature, compression=compression, protocol=protocol)
+    print(f"Opening project {fn}")
+    print(f"with params {res}")
+    signature = pf.fullVersion()
+    with draw.busyCursor():  # loading  may take a while
+        proj = project.Project(signature=signature, **res)
     if proj.signature != signature:
         pf.warning("The project was written with %s, while you are now running %s. If the latter is the newer one, this should probably not cause any problems. Saving is always done in the current format of the running version. Save your project and this message will be avoided on the next reopening." % (proj.signature, signature))
 
@@ -203,7 +212,7 @@ def createProject():
     """
     closeProject()
     proj = openProject(pf.PF.filename, exist=False)
-    if proj is not None:  # may be empty
+    if proj is not None:  # a project was selected
         setProject(proj)
 
 
@@ -214,7 +223,7 @@ def openExistingProject():
     """
     closeProject()
     proj = openProject(pf.PF.filename, exist=True)
-    if proj is not None:  # may be empty
+    if proj is not None:  # a project was selected
         setProject(proj)
 
 
@@ -280,7 +289,7 @@ def saveProject():
         print("Saving Project contents: %s" % pf.PF.contents())
         # Always put the current version is projects saved from file menu!
         pf.PF.signature = pf.fullVersion()
-        with busyCursor():
+        with draw.busyCursor():
             pf.PF.save()
 
 
@@ -308,7 +317,7 @@ def saveAsProject():
             'curproj': pf.PF.filename,
             'workdir': Path(pf.PF.filename).parent,
             }, save=True)
-    pf.GUI.setcurproj(pf.PF.filename)
+        pf.GUI.setcurproj(pf.PF.filename)
 
 
 def listProject():
@@ -389,12 +398,8 @@ def openScript(fn=None, exist=True, create=False):
     if fn is not None:
         fn = Path(fn)
     else:
-        cur = pf.cfg['curfile']
-        if cur is None:
-            cur = pf.cfg['workdir']
-        if cur is None:
-            cur  = '.'
-        fn = widgets.FileDialog(cur, 'pyformex', exist=exist).getFilename()
+        mode='exist' if exist else 'file'
+        fn = draw.askFilename(pf.cfg['curfile'], 'pyformex', mode=mode)
     if fn:
         if create:
             if not exist and fn.exists() and not draw.ack("The file %s already exists.\n Are you sure you want to overwrite it?" % fn):
@@ -403,6 +408,7 @@ def openScript(fn=None, exist=True, create=False):
             if template.exists():
                 template.copy(fn)
         updateSettings({'workdir': fn.parent}, save=True)
+        draw.chdir(fn)
         pf.GUI.setcurfile(fn)
         pf.GUI.scripthistory.add(fn)
         if create:
@@ -457,9 +463,9 @@ def saveImage(multi=False):
      - start the multisave/autosave mode
      - do nothing
     """
-    dia = dialogs.SaveImageDialog(pf.cfg['workdir'], ['img', 'icon', 'all'],
-                                  multi=multi)
+    dia = dialogs.SaveImageDialog(multi=multi)
     res = dia.getResults()
+
     if res:
         del res['set_size']
         pf.debug(res, pf.DEBUG.IMAGE)
@@ -534,7 +540,7 @@ def createMovieInteractive():
     if not res:
         return
 
-    with busyCursor():
+    with draw.busyCursor():
         image.createMovie(**res)
 
 
@@ -547,7 +553,7 @@ def createMovieInteractive():
 #     from pyformex.plugins.webgl import WebGL
 #     fn = draw.askNewFilename(pf.cfg['workdir'], ['pgf', 'all'])
 #     if fn:
-#         with busyCursor():
+#         with draw.busyCursor():
 #             print("Exporting current scene to %s" % fn)
 #             fn = fn.with_suffix('.pgf')
 #             W = WebGL(fn.stem)
@@ -616,13 +622,8 @@ def recordSession():
     utils.External.require('ffmpeg')
     dia =  dialogs.RecordSessionDialog(pf.cfg['workdir'])
     res = dia.getResults()
-    if not res:
-        return
-
-    #TODO: ask to overwrite it?, and delete it
-    #if fn.exists():
-    #    pass
-    image.recordSession(**res)
+    if res:
+        image.recordSession(**res)
 
 
 MenuData = (_('&File'), [
