@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -184,7 +184,7 @@ def settings():
         _I('_info_01_', 'The settings on this page will only become active after restarting pyFormex', itemtype='info'),
         _I('gui/bindings', bindings_current, choices=bindings_choices, tooltip="The Python bindings for the Qt libraries"),
         #_I('gui/interpreter',interpreter_current,choices=interpreter_choices,tooltip="The Python interpreter to use for the message board"),
-        _I('gui/splash', text='Splash image', itemtype='filename', filter='img', exist=True, preview=splashviewer),
+        _I('gui/splash', text='Splash image', itemtype='filename', filter='img', mode='exist', preview=splashviewer),
         splashviewer,
     ]
     ##### GUI settings #####
@@ -210,27 +210,28 @@ def settings():
         _I('gui/timeoutvalue', pf.cfg['gui/timeoutvalue']),
     ]
     gui_options2 = [
-        _I('gui/frontview', pf.cfg['gui/defviews'], itemtype='hradio', choices=['xy', 'xz'], tooltip="Axes defining the front view"),
-        _I('gui/showfocus', pf.cfg['gui/showfocus']),
         _I('gui/buttonsattop', pf.cfg['gui/buttonsattop']),
+        _I('gui/smart_placement', pf.cfg['gui/showfocus']),
         _I('gui/allow_old_dialog_items', pf.cfg['gui/allow_old_dialog_items']),
         _I('gui/easter_egg', pf.cfg['gui/easter_egg']),
     ]
     gui_settings = [
         _G('Appearance', gui_appearance),
         _G('Components', [
-            _C('col1', gui_components),
-            _C('col2', gui_buttons, spacer=True),
+            _C('col1', gui_components,),
+            _C('col2', gui_buttons, spacer='l'),
         ]),
         _G('Options', [
-            _C('col1',gui_options1),
-            _C('col2',gui_options2),
+            _C('col1',gui_options1,),
+            _C('col2',gui_options2, spacer='l'),
         ]),
     ]
 
     ##### CANVAS settings #####
     canvas_settings = [
-        _I('_not_active_', 'The canvas settings can be set from the Viewport Menu', itemtype='info', text=''),
+        _I('gui/frontview', pf.cfg['gui/defviews'], itemtype='hradio', choices=['xy', 'xz'], tooltip="Axes defining the front view"),
+        _I('gui/showfocus', pf.cfg['gui/showfocus']),
+        _I('_not_active_', 'More canvas settings can be set from the Viewport Menu', itemtype='info', text=''),
     ]
 
     ##### DRAWING settings #####
@@ -268,7 +269,7 @@ def settings():
     guiscripts.append('custom')
     webgl_settings = [
         _I('webgl/script', pf.cfg['webgl/script'], text='WebGL base script', choices=scripts),
-        _I('_webgl_script', '', text='URL for local WebGL base script', itemtype='filename', filter='js', exist=True),
+        _I('_webgl_script', '', text='URL for local WebGL base script', itemtype='filename', filter='js', mode='exist'),
         _I('webgl/guiscript', pf.cfg['webgl/guiscript'], text='GUI base script', choices=guiscripts),
         _I('_webgl_guiscript', '', text='URL for local GUI base script'),
         _I('webgl/autogui', pf.cfg['webgl/autogui'], text='Always add a standard GUI'),
@@ -309,15 +310,14 @@ def settings():
         ],
         # enablers=enablers,
         actions=[
-            ('Close', close),
-            ('Apply and Continue', accept),
-            ('Accept, Save and Close', acceptAndSave),
+            ('Cancel', close),
+            ('Accept', accept),
+            ('Accept and Save', acceptAndSave),
         ],
     )
     dia.show()
 
 
-
 def askConfigPreferences(items, prefix=None, store=None):
     """Ask preferences stored in config variables.
 
@@ -533,6 +533,7 @@ def addAppdir(path, name=None, dircfg='appdirs'):
     appMenu.reloadMenu(mode=dircfg[:-4])
 
 
+# TODO: this should be moved to gui.dialogs
 def createDirsDialog(dircfg):
     """Create a Dialog to set a list of paths.
 
@@ -548,8 +549,7 @@ def createDirsDialog(dircfg):
         title='Script paths'
 
     def insertRow():
-        ww = widgets.FileDialog(pf.cfg['workdir'], '*', exist=True, dir=True)
-        fn = ww.getFilename()
+        fn = draw.askDirname(pf.cfg['workdir'], '*', change=False)
         if fn:
             _table.model().insertRows()
             _table.model()._data[-1] = [fn.name.capitalize(), fn]
