@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -31,6 +31,7 @@ from gettext import gettext as _
 import pyformex as pf
 from pyformex import Path
 from pyformex import utils
+from pyformex import arraytools as at
 from pyformex.gui import widgets, draw, views
 from pyformex.opengl import canvas
 from pyformex.gui.draw import _I
@@ -90,13 +91,13 @@ def setGrid():
 def setBgColor():
     """Interactively set the viewport background colors."""
     global bgcolor_dialog
-    from pyformex.opengl.sanitize import saneColorArray
-    from numpy import resize
-    from pyformex.opengl import colors
+    from pyformex.opengl.sanitize import saneColor
     bgmodes = pf.canvas.settings.bgcolor_modes
     mode = pf.canvas.settings.bgmode
-    color = saneColorArray(pf.canvas.settings.bgcolor, (4,))
-    color = resize(color, (4, 3))
+    print(pf.canvas.settings.bgcolor)
+    color = saneColor(pf.canvas.settings.bgcolor).reshape(-1,3)
+    if color.shape[0] != 4:
+        color = at.resizeAxis(color, 4, 0)
     cur = Path(pf.canvas.settings.bgimage)
     showimage = cur.exists()
     if not showimage:
@@ -118,7 +119,7 @@ def setBgColor():
             _I('color3', color[2], itemtype='color', func=changeColor, text='Background color 3 (Top Right)'),
             _I('color4', color[3], itemtype='color', func=changeColor, text='Background color 4 (Top Left'),
             _I('showimage', showimage, text='Show background image'),
-            _I('image', cur, text='Background image', itemtype='filename', filter='img', exist=True, preview=viewer),
+            _I('image', cur, text='Background image', itemtype='filename', filter='img', mode='exist', preview=viewer),
             viewer,
             _I('_save_', False, text='Save as default'),
             ],
