@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -40,10 +40,7 @@ Distributed under the GNU GPL version 3 or later
 """
 
 from collections import defaultdict
-try:
-    from collections.abc import Mapping
-except Exception:
-    from collections import Mapping
+from collections.abc import Mapping
 
 
 def formatDict(d, indent=4):
@@ -57,16 +54,36 @@ def formatDict(d, indent=4):
     allowed in Python variable names, the resulting text is a legal
     Python script to define the items in the dict. It can be stored
     on a file and executed.
+
+    >>> d = {'y':'s', 'x':'t'}
+    >>> D = {'a':0, 'd':d, 'b':1}
+    >>> print(formatDict(D))
+    {
+        'a': 0,
+        'd': {'y': 's', 'x': 't'},
+        'b': 1,
+        }
+    >>> D = {'a':0, 'd':Dict(d), 'b':1}
+    >>> print(formatDict(D))
+    {
+        'a': 0,
+        'd': {
+            'y': 's',
+            'x': 't',
+        },
+        'b': 1,
+    }
     """
+    global default_indent
     s = "{\n"
     for k, v in d.items():
-        s += "%s'%s' : " % (' ' * indent, k)
+        s += "%s'%s': " % (' ' * indent, k)
         if isinstance(v, Dict):
             s += formatDict(v, indent + 4)
         else:
             s += "%r" % v
         s += ",\n"
-    s += "%s}" % (' ' * indent)
+    s += "%s}" % (' ' * (indent-4))
     return s
 
 
