@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -21,32 +21,8 @@
 ##  You should have received a copy of the GNU General Public License
 ##  along with this program.  If not, see http://www.gnu.org/licenses/.
 ##
-"""Initialization of the pyFormex opengl module.
+"""pyFormex subpackage.
 
-The opengl module contains everything related to the new OpenGL2 engine
-of pyFormex. The initialization can make changes to the other
-pyFormex modules in order to keep them working with the new engine.
+Do not remove this file. It is used by Python to mark the
+directory as a pyFormex subpackage.
 """
-
-#### Set the Formex and Mesh actor method ####
-
-def _set_actors():
-    def actor(self, **kargs):
-
-        if self.nelems() == 0:
-            return None
-
-        from pyformex.opengl.drawable import Actor
-
-        return Actor(self, **kargs)
-
-    from pyformex import formex
-    formex.Formex.actor = actor
-    from pyformex import mesh
-    mesh.Mesh.actor = actor
-
-#_set_actors()
-
-
-
-# End
