@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,12 +26,30 @@
 This module defines all OpenGL Actors that are directly available to the users.
 
 """
+import numpy as np
+from numpy import int32, float32
+from .gl import GL
 
+import pyformex as pf
+from pyformex import utils
+from pyformex import colors
+from pyformex import geomtools as gt
 from pyformex import arraytools as at
-from pyformex.opengl.drawable import Actor
-# This is to make alle Actors available through this module
-from pyformex.opengl.decors import *
-from pyformex.opengl.textext import *
+from pyformex.formex import Formex
+from pyformex.mesh import Mesh
+from pyformex.attributes import Attributes
+from pyformex.elements import ElementType
+from .sanitize import saneFloat, saneLineStipple, saneColorSet
+from .texture import Texture
+
+if not pf.sphinx and pf.options.gl3:
+    from pyformex.opengl3.drawable import Actor
+else:
+    from .drawable import Actor
+
+# We import the other Actors, so they they all can be imported from actors.
+from .textext import *
+from .decors import *
 
 
 #  TODO: this replaces legacy PlaneActor, but could probably be derived from
