@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -34,41 +34,13 @@ the current OpenGL framework in pyFormex.
 """
 
 import numpy as np
-import OpenGL.GL as GL
-
-from pyformex.opengl.matrix import Matrix4, Vector4
 from pyformex import arraytools as at
 from pyformex.coords import Coords
 from pyformex.plugins.nurbs import Coords4
 from pyformex.config import Config
 
-#
-# DEVS: collect all GL calls here, so we can easily move them somewhere else
-#
-
-def gl_projection():
-    """Get the OpenGL projection matrix"""
-    return GL.glGetDoublev(GL.GL_PROJECTION_MATRIX)
-def gl_modelview():
-    """Get the OpenGL modelview matrix"""
-    return GL.glGetDoublev(GL.GL_MODELVIEW_MATRIX)
-def gl_viewport():
-    """Get the OpenGL viewport"""
-    return GL.glGetIntegerv(GL.GL_VIEWPORT)
-def gl_loadmodelview(m):
-    """Load the OpenGL modelview matrix"""
-    GL.glMatrixMode(GL.GL_MODELVIEW)
-    GL.glLoadMatrixf(m)
-def gl_loadprojection(m):
-    """Load the OpenGL projection matrix"""
-    GL.glMatrixMode(GL.GL_PROJECTION)
-    GL.glLoadMatrixf(m)
-    # we reset OpenGL engine to default MODELVIEW
-    GL.glMatrixMode(GL.GL_MODELVIEW)
-def gl_depth(x, y):
-    """Read the depth value of the pixel at (x,y)"""
-    return GL.glReadPixels(x, y, 1, 1, GL.GL_DEPTH_COMPONENT, GL.GL_FLOAT)
-
+from .matrix import Matrix4, Vector4
+from . import gl
 
 #
 # Normalize and denormalize should probably be moved to arraytools.
@@ -349,7 +321,7 @@ class Camera(object):
         This property can not be changed directly.
         It should be changed by resizing the parent canvas.
         """
-        return gl_viewport()
+        return gl.gl_viewport()
 
 
     @property
@@ -803,7 +775,7 @@ class Camera(object):
         Then, the current Projection matrix of the camera is loaded into the
         OpenGL engine.
         """
-        gl_loadprojection(self.projection.gl())
+        gl.gl_loadprojection(self.projection.gl())
 
 
 
@@ -967,7 +939,7 @@ class Camera(object):
         Then, the current Modelview matrix of the camera is loaded into the
         OpenGL engine.
         """
-        gl_loadmodelview(self.modelview.gl())
+        gl.gl_loadmodelview(self.modelview.gl())
 
 
     def toEye(self, x):
@@ -1005,7 +977,7 @@ class Camera(object):
         """Convert normalized device coordinates to window coordinates"""
         # This is only correct when glDepthRange(0.0, 1.0)
         # We should not change the depth range
-        vp = gl_viewport()
+        vp = gl.gl_viewport()
         #print([[vp[0], vp[1], 0], [vp[2], vp[3], 1]])
         return denormalize(x[:, :3], [[vp[0], vp[1], 0], [vp[2], vp[3], 1]])
 
@@ -1014,7 +986,7 @@ class Camera(object):
         """Convert window coordinates to  normalized device coordinates"""
         # This is only correct when glDepthRange(0.0, 1.0)
         # We should not change the depth range
-        vp = gl_viewport()
+        vp = gl.gl_viewport()
         x = at.checkArray(x, (-1, 3), 'f')
         return normalize(x[:, :3], [[vp[0], vp[1], 0], [vp[2], vp[3], 1]])
 
