@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,521 +24,86 @@
 """This implements an OpenGL drawing widget for painting 3D scenes.
 
 """
-
 import numpy as np
 
-from OpenGL import GL, GLU
-
 import pyformex as pf
 
+from . import gl
+from .gl import GL, GLU
+
 from pyformex import utils
 from pyformex import arraytools as at
+from pyformex import colors
 from pyformex.coords import Coords, bbox
 from pyformex.mydict import Dict
-from collections import OrderedDict
 from pyformex.collection import Collection
 from pyformex.simple import cuboid2d
-from pyformex.opengl import decors
-from pyformex.opengl import colors
-from .sanitize import saneColor
-from .drawable import Actor
-from .camera import Camera
-from .renderer import Renderer
-from .scene import Scene, ItemList
 from pyformex.gui import views
+from .sanitize import saneColor
+from .canvas_settings import CanvasSettings, Light, LightProfile
+from .scene import Scene, ItemList
+from .renderer import Renderer
+from .actors import Actor
+from .camera import Camera
+from .decors import Grid2D
+
+### Some (OLD) drawing functions ############################################
+
+# But still kept because used!
+
+def drawDot(x, y):
+    """Draw a dot at canvas coordinates (x,y)."""
+    GL.glBegin(GL.GL_POINTS)
+    GL.glVertex2f(x, y)
+    GL.glEnd()
 
 
-def glVersion(mode='all'):
-    return OrderedDict([
-        ('vendor', str(GL.glGetString(GL.GL_VENDOR))),
-        ('renderer', str(GL.glGetString(GL.GL_RENDERER))),
-        ('version', str(GL.glGetString(GL.GL_VERSION))),
-        ('glsl_version', str(GL.glGetString(GL.GL_SHADING_LANGUAGE_VERSION))),
-        ])
+def drawLine(x1, y1, x2, y2):
+    """Draw a straight line from (x1,y1) to (x2,y2) in canvas coordinates."""
+    GL.glBegin(GL.GL_LINES)
+    GL.glVertex2f(x1, y1)
+    GL.glVertex2f(x2, y2)
+    GL.glEnd()
 
 
-libGL = None
+def drawGrid(x1, y1, x2, y2, nx, ny):
+    """Draw a rectangular grid of lines
 
-def loadLibGL():
-    # TODO: UGLY! WE SHOULD GET RID OF THIS
-    global libGL
-    if libGL is None and pf.X11:
-        from ctypes import cdll
-        libGL = cdll.LoadLibrary("libGL.so.1")
-
-
-def gl_pickbuffer():
-    "Return a list of the 2nd numbers in the openGL pick buffer."
-    buf = GL.glRenderMode(GL.GL_RENDER)
-    return np.asarray([r[2] for r in buf])
-
-# Used in CanvasSettings.glOverride !
-from OpenGL.GL import glLineWidth as glLinewidth, glPointSize as glPointsize
-
-fill_modes = [GL.GL_FRONT_AND_BACK, GL.GL_FRONT, GL.GL_BACK]
-fill_mode = GL.GL_FRONT_AND_BACK
-
-def glFillMode(mode):
-    global fill_mode
-    if mode in fill_modes:
-        fill_mode = mode
-def glFrontFill():
-    glFillMode(GL.GL_FRONT)
-def glBackFill():
-    glFillMode(GL.GL_BACK)
-def glBothFill():
-    glFillMode(GL.GL_FRONT_AND_BACK)
-
-def glFill(fill=True):
-    if fill:
-        GL.glPolygonMode(fill_mode, GL.GL_FILL)
+    The rectangle has (x1,y1) and and (x2,y2) as opposite corners.
+    There are (nx,ny) subdivisions along the (x,y)-axis. So the grid
+    has (nx+1) * (ny+1) lines. nx=ny=1 draws a rectangle.
+    nx=0 draws 1 vertical line (at x1). nx=-1 draws no vertical lines.
+    ny=0 draws 1 horizontal line (at y1). ny=-1 draws no horizontal lines.
+    """
+    GL.glBegin(GL.GL_LINES)
+    ix = range(nx+1)
+    if nx==0:
+        jx = [1]
+        nx = 1
     else:
-        GL.glPolygonMode(GL.GL_FRONT_AND_BACK, GL.GL_LINE)
+        jx = ix[::-1]
+    for i, j in zip(ix, jx):
+        x = (i*x2+j*x1)/nx
+        GL.glVertex2f(x, y1)
+        GL.glVertex2f(x, y2)
 
-def glLineSmooth(onoff):
-    if onoff is True:
-        GL.glEnable(GL.GL_LINE_SMOOTH)
-        GL.glHint(GL.GL_LINE_SMOOTH_HINT, GL.GL_NICEST)
-    elif onoff is False:
-        GL.glDisable(GL.GL_LINE_SMOOTH)
-
-
-def glLineStipple(factor, pattern):
-    """Set the line stipple pattern.
-
-    When drawing lines, OpenGl can use a stipple pattern. The stipple
-    is defined by two values: a pattern (on/off) of maximum 16 bits,
-    used on the pixel level, and a multiplier factor for each bit.
-
-    If factor <= 0, the stippling is disabled.
-    """
-    print("Line stipple is currently not supported with gl2 engine")
-    ## if factor > 0:
-    ##     GL.glLineStipple(factor, pattern)
-    ##     GL.glEnable(GL.GL_LINE_STIPPLE)
-    ## else:
-    ##     GL.glDisable(GL.GL_LINE_STIPPLE)
-
-def glSmooth(smooth=True):
-    """Enable smooth shading"""
-    if smooth:
-        GL.glShadeModel(GL.GL_SMOOTH)
+    iy = range(ny+1)
+    if ny==0:
+        jy = [1]
+        ny = 1
     else:
-        GL.glShadeModel(GL.GL_FLAT)
+        jy = iy[::-1]
+    for i, j in zip(iy, jy):
+        y = (i*y2+j*y1)/ny
+        GL.glVertex2f(x1, y)
+        GL.glVertex2f(x2, y)
+    GL.glEnd()
 
-def glFlat():
-    """Disable smooth shading"""
-    glSmooth(False)
 
+def drawRect(x1, y1, x2, y2):
+    """Draw the circumference of a rectangle."""
+    drawGrid(x1, y1, x2, y2, 1, 1)
 
-def onOff(onoff):
-    """Convert On/Off strings to a boolean"""
-    if isinstance(onoff, str):
-        return (onoff.lower() == 'on')
-    else:
-        if onoff:
-            return True
-        else:
-            return False
-
-
-def glEnable(facility, onoff):
-    """Enable/Disable an OpenGL facility, depending on onoff value
-
-    facility is an OpenGL facility.
-    onoff can be True or False to enable, resp. disable the facility, or
-    None to leave it unchanged.
-    """
-    #pf.debug("%s: %s" % (facility,onoff),pf.DEBUG.DRAW)
-    if onOff(onoff):
-        #pf.debug("ENABLE",pf.DEBUG.DRAW)
-        GL.glEnable(facility)
-    else:
-        #pf.debug("DISABLE",pf.DEBUG.DRAW)
-        GL.glDisable(facility)
-
-
-def glCulling(onoff=True):
-    glEnable(GL.GL_CULL_FACE, onoff)
-def glNoCulling():
-    glCulling(False)
-
-
-def glPolygonFillMode(mode):
-    if isinstance(mode, str):
-        mode = mode.lower()
-        if mode == 'Front and Back':
-            glBothFill()
-        elif mode == 'Front':
-            glFrontFill()
-        elif mode == 'Back':
-            glBackFill()
-
-
-def glPolygonMode(mode):
-    if isinstance(mode, str):
-        mode = mode.lower()
-        glFill(mode == 'fill')
-
-
-def glShadeModel(model):
-    if isinstance(model, str):
-        model = model.lower()
-        if model == 'smooth':
-            glSmooth()
-        elif model == 'flat':
-            glFlat()
-
-
-def glPolygonOffset(value):
-    if value <= 0.0:
-        GL.glDisable(GL.GL_POLYGON_OFFSET_FILL)
-    else:
-        GL.glEnable(GL.GL_POLYGON_OFFSET_FILL)
-        GL.glPolygonOffset(value, value)
-
-
-def glViewport():
-    """Return the current OpenGL Viewport
-
-    Returns a tuple x,y,w,h spcifying the position and size of the
-    current OpenGL viewport (in pixels).
-    """
-    return GL.glGetIntegerv(GL.GL_VIEWPORT)
-
-
-############### OpenGL Lighting #################################
-
-class Material(object):
-    def __init__(self, name, ambient=0.2, diffuse=0.2, specular=0.9, emission=0.1, shininess=2.0):
-        self.name = str(name)
-        self.ambient = float(ambient)
-        self.diffuse = float(diffuse)
-        self.specular = float(specular)
-        self.emission = float(emission)
-        self.shininess = float(shininess)
-
-
-    def setValues(self, **kargs):
-        #print "setValues",kargs
-        for k in kargs:
-            #print k,kargs[k]
-            if hasattr(self, k):
-                #print getattr(self,k)
-                setattr(self, k, float(kargs[k]))
-                #print getattr(self,k)
-
-
-    def dict(self):
-        """Return the material light parameters as a dict"""
-        return dict([(k, getattr(self, k)) for k in ['ambient', 'diffuse', 'specular', 'emission', 'shininess']])
-
-
-    def __str__(self):
-        return """MATERIAL: %s
-    ambient:  %s
-    diffuse:  %s
-    specular: %s
-    emission: %s
-    shininess: %s
-""" % (self.name, self.ambient, self.diffuse, self.specular, self.emission, self.shininess)
-
-
-def getMaterials():
-    mats = pf.refcfg['material']
-    mats.update(pf.prefcfg['material'])
-    mats.update(pf.cfg['material'])
-    return mats
-
-
-def createMaterials():
-    mats = getMaterials()
-    matdb = {}
-    for m in mats:
-        matdb[m] = Material(m, **mats[m])
-    return matdb
-
-
-class Light(object):
-    """A class representing an OpenGL light.
-
-    The light can emit 3 types of light: ambient, diffuse and specular,
-    which can have different color and are all off by default.
-
-
-    """
-
-    def __init__(self, ambient=0.0, diffuse=0.0, specular=0.0, position=[0., 0., 1.], enabled=True):
-        self.setValues(ambient, diffuse, specular, position)
-        self.enable(enabled)
-
-    def setValues(self, ambient=None, diffuse=None, specular=None, position=None):
-        if ambient is not None:
-            self.ambient = colors.GLcolor(ambient)
-        if diffuse is not None:
-            self.diffuse = colors.GLcolor(diffuse)
-        if specular is not None:
-            self.specular = colors.GLcolor(specular)
-        if position is not None:
-            self.position = at.checkArray(position, (3,), 'f')
-
-    def enable(self, onoff=True):
-        self.enabled = bool(onoff)
-
-    def disable(self):
-        self.enable(False)
-
-
-    def __str__(self, name=''):
-        return """LIGHT%s (enabled: %s):
-    ambient color:  %s
-    diffuse color:  %s
-    specular color: %s
-    position: %s
-""" % (name, self.enabled, self.ambient, self.diffuse, self.specular, self.position)
-
-
-class LightProfile(object):
-    """A lightprofile contains all the lighting parameters.
-
-    Currently this consists off:
-    - `ambient`: the global ambient lighting (currently a float)
-    - `lights`: a list of 1 to 4 Lights
-    """
-
-    def __init__(self, ambient, lights):
-        self.ambient = ambient
-        self.lights = lights
-
-
-    def __str__(self):
-        s = """LIGHTPROFILE:
-    global ambient:  %s
-    """ % self.ambient
-        for i, l in enumerate(self.lights):
-            s += '  ' + l.__str__(i)
-        return s
-
-
-##################################################################
-#
-#  The Canvas Settings
-#
-
-
-class CanvasSettings(Dict):
-    """A collection of settings for an OpenGL Canvas.
-
-    The canvas settings are a collection of settings and default values
-    affecting the rendering in an individual viewport. There are two type of
-    settings:
-
-    - mode settings are set during the initialization of the canvas and
-      can/should not be changed during the drawing of actors and decorations;
-    - default settings can be used as default values but may be changed during
-      the drawing of actors/decorations: they are reset before each individual
-      draw instruction.
-
-    Currently the following mode settings are defined:
-
-    - bgmode: the viewport background color mode
-    - bgcolor: the viewport background color: a single color or a list of
-      colors (max. 4 are used).
-    - bgimage: background image filename
-    - slcolor: the highlight color
-    - alphablend: boolean (transparency on/off)
-
-    The list of default settings includes:
-
-    - fgcolor: the default drawing color
-    - bkcolor: the default backface color
-    - colormap: the default color map to be used if color is an index
-    - bklormap: the default color map to be used if bkcolor is an index
-    - smooth: boolean (smooth/flat shading)
-    - lighting: boolean (lights on/off)
-    - culling: boolean
-    - transparency: float (0.0..1.0)
-    - avgnormals: boolean
-    - wiremode: integer -3..3
-    - pointsize: the default size for drawing points
-    - marksize: the default size for drawing markers
-    - linewidth: the default width for drawing lines
-
-    Any of these values can be set in the constructor using a keyword argument.
-    All items that are not set, will get their value from the configuration
-    file(s).
-    """
-
-    # A collection of default rendering profiles.
-    # These contain the values different from the overall defaults
-    RenderProfiles = {
-        'wireframe': Dict({
-            'smooth': False,
-            'fill': False,
-            'lighting': False,
-            'alphablend': False,
-            'transparency': 1.0,
-            'wiremode': -1,
-            'avgnormals': False,
-            }),
-        'smooth': Dict({
-            'smooth': True,
-            'fill': True,
-            'lighting': True,
-            'alphablend': False,
-            'transparency': 0.5,
-            'wiremode': -1,
-            'avgnormals': False,
-            }),
-        'smooth_avg': Dict({
-            'smooth': True,
-            'fill': True,
-            'lighting': True,
-            'alphablend': False,
-            'transparency': 0.5,
-            'wiremode': -1,
-            'avgnormals': True,
-            }),
-        'smoothwire': Dict({
-            'smooth': True,
-            'fill': True,
-            'lighting': True,
-            'alphablend': False,
-            'transparency': 0.5,
-            'wiremode': 1,
-            'avgnormals': False,
-            }),
-        'flat': Dict({
-            'smooth': False,
-            'fill': True,
-            'lighting': False,
-            'alphablend': False,
-            'transparency': 0.5,
-            'wiremode': -1,
-            'avgnormals': False,
-            }),
-        'flatwire': Dict({
-            'smooth': False,
-            'fill': True,
-            'lighting': False,
-            'alphablend': False,
-            'transparency': 0.5,
-            'wiremode': 1,
-            'avgnormals': False,
-            }),
-        }
-    bgcolor_modes = ['solid', 'vertical', 'horizontal', 'full']
-    edge_modes = ['none', 'feature', 'all']
-
-    def __init__(self, **kargs):
-        """Create a new set of CanvasSettings."""
-        Dict.__init__(self)
-        self.reset(kargs)
-
-    def reset(self, d={}):
-        """Reset the CanvasSettings to its defaults.
-
-        The default values are taken from the configuration files.
-        An optional dictionary may be specified to override (some of) these defaults.
-        """
-        self.update(pf.refcfg['canvas'])
-        self.update(self.RenderProfiles[pf.prefcfg['draw/rendermode']])
-        self.update(pf.prefcfg['canvas'])
-        self.update(pf.cfg['canvas'])
-        if d:
-            self.update(d)
-
-    def update(self, d, strict=True):
-        """Update current values with the specified settings
-
-        Returns the sanitized update values.
-        """
-        ok = self.checkDict(d, strict)
-        Dict.update(self, ok)
-
-    @classmethod
-    def checkDict(clas, dict, strict=True):
-        """Transform a dict to acceptable settings."""
-        ok = {}
-        for k, v in dict.items():
-            try:
-                if k in ['bgcolor', 'fgcolor', 'bkcolor', 'slcolor',
-                          'colormap', 'bkcolormap']:
-                    if v is not None:
-                        v = saneColor(v)
-                elif k in ['bgimage']:
-                    v = str(v)
-                elif k in ['smooth', 'fill', 'lighting', 'culling',
-                           'alphablend', 'avgnormals', ]:
-                    v = bool(v)
-                elif k in ['linewidth', 'pointsize', 'marksize']:
-                    v = float(v)
-                elif k in ['wiremode']:
-                    v = int(v)
-                elif k == 'linestipple':
-                    v = [int(vi) for vi in v]
-                elif k == 'transparency':
-                    v = max(min(float(v), 1.0), 0.0)
-                elif k == 'bgmode':
-                    v = str(v).lower()
-                    if not v in clas.bgcolor_modes:
-                        raise
-                elif k == 'marktype':
-                    pass
-                else:
-                    raise
-                ok[k] = v
-            except Exception:
-                if strict:
-                    raise ValueError("Invalid key/value for CanvasSettings: %s = %s" % (k, v))
-        return ok
-
-    def __str__(self):
-        return utils.formatDict(self)
-
-
-    ## def setMode(self):
-    ##     """Activate the mode canvas settings in the GL machine."""
-    ##     GL.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT)
-    ##     if self.bgcolor.ndim > 1:
-    ##         color = self.bgcolor[0]
-    ##     else:
-    ##         color = self.bgcolor
-    ##     GL.glClearColor(*colors.RGBA(color))
-
-
-    def activate(self):
-        """Activate the default canvas settings in the GL machine."""
-        self.glOverride(self, self)
-
-
-    @staticmethod
-    def glOverride(settings, default):
-        for k in settings:
-            if k in ['smooth', 'fill', 'linewidth', 'pointsize']:
-                func = globals()['gl'+k.capitalize()]
-                func(settings[k])
-
-
-### OLD: to be rmoved (still used in viewport)
-def glSettings(settings):
-    pf.debug("GL SETTINGS: %s" % settings, pf.DEBUG.DRAW)
-    glShadeModel(settings.get('Shading', None))
-    glCulling(settings.get('Culling', None))
-    #glLighting(settings.get('Lighting', None))
-    glLineSmooth(onOff(settings.get('Line Smoothing', None)))
-    glPolygonFillMode(settings.get('Polygon Fill', None))
-    glPolygonMode(settings.get('Polygon Mode', None))
-    pf.canvas.update()
-
-
-def extractCanvasSettings(d):
-    """Split a dict in canvas settings and other items.
-
-    Returns a tuple of two dicts: the first one contains the items
-    that are canvas settings, the second one the rest.
-    """
-    return utils.select(d, pf.refcfg['canvas']), utils.remove(d, pf.refcfg['canvas'])
 
 #############################################################################
 #############################################################################
@@ -548,6 +113,7 @@ def extractCanvasSettings(d):
 #############################################################################
 #############################################################################
 
+
 def print_camera(self):
     print(self.report())
 
@@ -587,8 +153,9 @@ class Canvas(object):
     def __init__(self, settings={}):
         """Initialize an empty canvas with default settings."""
         from pyformex.gui import views
-        loadLibGL()
+        #loadLibGL()
         self.scene = Scene(self)
+        self.renderer = None
         self.highlights = ItemList(self)
         self.camera = None
         self.triade = None
@@ -601,6 +168,7 @@ class Canvas(object):
         self.cursor = None
         self._focus = None
         self.focus = False
+        self.state = (0,0)
         pf.debug("Canvas Setting:\n%s"% self.settings, pf.DEBUG.DRAW)
         self.makeCurrent()  # we need correct OpenGL context
 
@@ -995,7 +563,11 @@ class Canvas(object):
         ## if pf.options.testcamera:
         ##     self.camera.modelview_callback = print_camera
         ##     self.camera.projection_callback = print_camera
-        self.renderer = Renderer(self)
+        # TODO: This could be a Renderer.set_camera instead of creating a new
+        if self.renderer is None:
+            self.renderer = Renderer(self)
+        else:
+            self.renderer.camera = self.camera
 
 
     def clearCanvas(self):
@@ -1051,11 +623,11 @@ class Canvas(object):
         self.clearCanvas()
         GL.glClearDepth(1.0)	       # Enables Clearing Of The Depth Buffer
         GL.glEnable(GL.GL_DEPTH_TEST)	       # Enables Depth Testing
-        #GL.glEnable(GL.GL_CULL_FACE)
+        GL.glEnable(GL.GL_CULL_FACE)
         if self.rendermode == 'wireframe':
-            glPolygonOffset(0.0)
+            gl.gl_polygonoffset(0.0)
         else:
-            glPolygonOffset(1.0)
+            gl.gl_polygonoffset(1.0)
 
 
     def glinit(self):
@@ -1065,9 +637,9 @@ class Canvas(object):
         self.reset()
 
 
-    def glupdate(self):
+    def glFinish(self):
         """Flush all OpenGL commands, making sure the display is updated."""
-        GL.glFlush()
+        GL.glFinish()
 
 
     # TODO: this is here for compatibility reasons
@@ -1113,8 +685,8 @@ class Canvas(object):
         self.makeCurrent()
 
         self.clearCanvas()
-        glSmooth()
-        glFill()
+        gl.gl_smooth()
+        gl.gl_fill()
 
         # # Set correct focus rectangle status
         # if self.focus:
@@ -1129,12 +701,12 @@ class Canvas(object):
                 self.setDefaults()
                 actor.draw(canvas=self)
 
-        # Draw the opengl2 actors
-        pf.debug("opengl2 shader rendering", pf.DEBUG.DRAW)
+        # Draw the opengl actors
+        pf.debug("opengl shader rendering", pf.DEBUG.DRAW)
         self.renderer.render(self.scene)
 
         # make sure canvas is updated
-        GL.glFlush()
+        self.glFinish()
 
 
     def zoom_2D(self, zoom=None):
@@ -1180,18 +752,18 @@ class Canvas(object):
 
 
 
-    # def addHighlight(self, itemlist):
-    #     """Add a highlight or a list thereof to the 3D scene"""
-    #     self.highlights.add(itemlist)
+    def addHighlight(self, itemlist):
+        """Add a highlight or a list thereof to the 3D scene"""
+        self.highlights.add(itemlist)
 
-    # def removeHighlight(self,itemlist=None):
-    #     """Remove a highlight or a list thereof from the 3D scene.
+    def removeHighlight(self,itemlist=None):
+        """Remove a highlight or a list thereof from the 3D scene.
 
-    #     Without argument, removes all highlights from the scene.
-    #     """
-    #     if itemlist is None:
-    #         itemlist = self.highlights[:]
-    #     self.highlights.delete(itemlist)
+        Without argument, removes all highlights from the scene.
+        """
+        if itemlist is None:
+            itemlist = self.highlights[:]
+        self.highlights.delete(itemlist)
 
 
     def addAny(self, itemlist):
@@ -1422,9 +994,8 @@ class Canvas(object):
 
     def add_focus_rectangle(self, color=colors.pyformex_pink):
         """Draw the focus rectangle."""
-        from . import decors
         if self._focus is None:
-            self._focus = decors.Grid2D(-1., -1., 1., 1., color=color, linewidth=2, rendertype=3)
+            self._focus = Grid2D(-1., -1., 1., 1., color=color, linewidth=2, rendertype=3)
             self._focus.sticky = True
         if self._focus not in self.scene.backgrounds:
             self.addAny(self._focus)
@@ -1439,12 +1010,11 @@ class Canvas(object):
 
     def draw_cursor(self, x, y):
         """draw the cursor"""
-        from . import decors
         if self.cursor:
             self.removeAny(self.cursor)
         w, h = pf.cfg['draw/picksize']
         col = pf.cfg['pick/color']
-        self.cursor = decors.Grid2D(x-w/2, y-h/2, x+w/2, y+h/2, color=col, linewidth=1)
+        self.cursor = Grid2D(x-w/2, y-h/2, x+w/2, y+h/2, color=col, linewidth=1)
         self.addAny(self.cursor)
 
 
@@ -1452,7 +1022,7 @@ class Canvas(object):
         if self.cursor:
             self.removeAny(self.cursor)
         col = pf.cfg['pick/color']
-        self.cursor = decors.Grid2D(self.statex, self.statey, x, y, color=col, linewidth=1)
+        self.cursor = Grid2D(self.statex, self.statey, x, y, color=col, linewidth=1)
         self.addAny(self.cursor)
 
 
