@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,29 +24,29 @@
 """OpenGL rendering objects for the new OpenGL2 engine.
 
 """
-
 import numpy as np
 from numpy import int32, float32
-from OpenGL import GL
+from .gl import GL
 from OpenGL.arrays.vbo import VBO
 
 import pyformex as pf
-from pyformex.opengl.sanitize import saneFloat, saneLineStipple, saneColorSet
-from pyformex.opengl import colors
-from pyformex.opengl.texture import Texture
-from pyformex.attributes import Attributes
-from pyformex.formex import Formex
-from pyformex.mesh import Mesh
-from pyformex.elements import ElementType
+from pyformex import utils
+from pyformex import colors
 from pyformex import geomtools as gt
 from pyformex import arraytools as at
-from pyformex import utils
+from pyformex.formex import Formex
+from pyformex.mesh import Mesh
+from pyformex.attributes import Attributes
+from pyformex.elements import ElementType
+from .sanitize import saneFloat, saneLineStipple, saneColorSet
+from .texture import Texture
 
 
 ### Drawable Objects ###############################################
 
 def size_report(s, a):
-    print('%s: size %s; shape %s; type %s' % (s, a.size, a.shape, a.dtype))
+    print(f"{s}: size {a.size}; shape {a.shape}; type {a.dtype}")
+
 
 def glObjType(nplex):
     if nplex <= 3:
@@ -206,6 +206,9 @@ class Drawable(Attributes):
                 self.useObjectColor = 1
                 self.objectColor = self.color
             elif self.color.ndim == 2:
+                # TODO: this can probably be removed, as we now convert
+                # element color to vertex color in the sanitize module
+                # ? DO WE ?
                 self.useObjectColor = 0
                 self.vertexColor = at.multiplex(self.color, self.object.nplex(), axis=-2, warn=False)
                 #pf.debug("Multiplexing colors: %s -> %s " % (self.color.shape, self.vertexColor.shape),pf.DEBUG.OPENGL)
@@ -215,28 +218,27 @@ class Drawable(Attributes):
 
             if self.vertexColor is not None:
                 #print("Shader suffix:[%s]" %  pf.options.shader)
-                if pf.options.shader == 'alpha':
+                if True: #pf.options.shader == 'alpha':
                     if self.alpha is None:
                         self.alpha = 0.5
                     if self.vertexColor.shape[-1] == 3:
                         # Expand to 4 !!!
-                        self.vertexColor = at.growAxis(self.vertexColor, 1, fill=self.alpha)
+                        self.vertexColor = at.growAxis(self.vertexColor, 1,
+                                                       fill=self.alpha)
                 self.cbo = VBO(self.vertexColor.astype(float32))
-                if pf.options.shader == 'alpha':
-                    size_report("Created cbo VBO", self.cbo)
+                #size_report("Created cbo VBO", self.cbo)
 
         self.rgbamode = self.useObjectColor == 0 and self.vertexColor.shape[-1] == 4
 
-        #### TODO: should we make this configurable ??
-        #
         #  !!!!!!!!!!!!   Fix a bug with AMD cards   !!!!!!!!!!!!!!!
         #
         #  it turns out that some? AMD? cards do not like an unbound cbo
         #  even if that attribute is not used in the shader.
         #  Creating a dummy color buffer seems to solve that problem
         #
-        if self.cbo is None:
-            self.cbo = VBO(np.array(colors.red))
+        if pf.options.fixcbo:
+            if self.cbo is None:
+                self.cbo = VBO(np.array(colors.red))
 
         #if self.rendertype == 3:
         #    print("CBO DATA %s\n" % self.name,self.cbo.data)
@@ -250,18 +252,16 @@ class Drawable(Attributes):
         """
         if self.useObjectColor:
             return
-        if pf.options.shader == 'alpha':
+        #size_report('color', color)
+        #size_report('cbo', self.cbo)
+        #print(self.cbo.size / color.size)
         #if color.size != self.cbo.size:
-            size_report('color', color)
-            size_report('cbo', self.cbo)
-            print(self.cbo.size / color.size)
-            print("Can not change vertex color from shape %s to shape %s" % (str(self.cbo.shape), str(color.shape)))
-            #return
+            #print("Can not change vertex color from shape %s to shape %s" % (str(self.cbo.shape), str(color.shape)))
+                #return
         self.vertexColor = self.color
         self.cbo = VBO(color.astype(float32))
-        if pf.options.shader == 'alpha':
-            print("Replace cbo with")
-            size_report('cbo', self.cbo)
+        #print("Replace cbo with")
+        size_report('cbo', self.cbo)
 
 
     def prepareTexture(self):
@@ -339,7 +339,6 @@ class Drawable(Attributes):
             x[:, :, 2] = 0
             self.vbo = VBO(x)
 
-
         self.vbo.bind()
         GL.glEnableVertexAttribArray(renderer.shader.attribute['vertexCoords'])
         GL.glVertexAttribPointer(renderer.shader.attribute['vertexCoords'], 3, GL.GL_FLOAT, False, 0, self.vbo)
@@ -457,7 +456,6 @@ class Drawable(Attributes):
 
 ########################################################################
 
-
 class BaseActor(Attributes):
     """Base class for all drawn objects (Actors) in pyFormex.
 
@@ -760,7 +758,9 @@ class Actor(BaseActor):
         Since the attributes may be dependent on the rendering mode,
         this method is called on each mode change.
         """
+        #print("Actor color in", self.color)
         self.color = self.okColor(self.color, self.colormap)
+        #print("okColor", self.color)
         self.bkcolor = self.okColor(self.bkcolor, self.bkcolormap)
         if self.color is not None:
             if self.color.ndim == 1:
@@ -832,11 +832,10 @@ class Actor(BaseActor):
             self.nbo = VBO(normals)
 
 
-
     def fullElems(self):
         """Return an elems index for the full coords set"""
         nelems, nplex = self.fcoords.shape[:2]
-        return np.arange(nelems*nplex).reshape(nelems, nplex)
+        return np.arange(nelems*nplex, dtype=int32).reshape(nelems, nplex)
 
 
     def subElems(self, nsel=None, esel=None):
@@ -1215,11 +1214,6 @@ class Actor(BaseActor):
         return s
 
 
-
-
-# for compatibility
-GeomActor = Actor
-
 ########################################################################
 
 
@@ -1236,49 +1230,4 @@ def polygonEdgeIndex(n):
     return np.column_stack([i0, i1])
 
 
-########################################################################
-
-## from pyformex import arraytools as at
-
-## class Text3DActor(OldActor):
-##     """A text as a 3D object.
-
-##     This class provides an Actor representing a text as an object
-##     in 3D space.
-##     """
-##     def __init__(self, text, font, facesize, color, trl):
-##         OldActor.__init__(self)
-##         self.text = text
-##         self.font = font
-##         self.setFaceSize(*facesize)
-##         self.setColor(color)
-##         self.trl = at.checkArray(trl, (3,), 'f')
-
-##     def setFaceSize(self, a, b):
-##         self.font.FaceSize(a, b)
-
-##     def setColor(self, color):
-##         from pyformex.opengl.sanitize import saneColor
-##         self.color = saneColor(color)
-
-##     def bbox(self):
-##         bb = self.font.BBox(self.text)
-##         return [bb[:3], bb[3:]]
-
-##     def render(self, renderer):
-##         """Render the geometry of this object"""
-##         GL.glMatrixMode(GL.GL_MODELVIEW)
-##         GL.glPushMatrix()
-##         GL.glTranslate(*self.trl)
-##         GL.glColor3fv(self.color)
-##         self.font.Render(self.text)
-##         GL.glMatrixMode(GL.GL_MODELVIEW)
-##         GL.glPopMatrix()
-##         # Because of the way font.Render works, we need an update here
-##         #pf.canvas.update()
-
-
-##     def draw(self,canvas):
-##         self.render(None)
-
 ### End
