@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,9 +29,9 @@ modify the rendered scene.
 """
 
 import pyformex as pf
-from pyformex.opengl.drawable import GeomActor
-from pyformex.gui.draw import _T, _G, _I, Dialog
-from pyformex.opengl.colors import GLcolor
+from .actors import Actor
+from pyformex import colors
+from pyformex.gui.widgets import _T, _G, _I, Dialog
 
 
 def objectDialog(obj=None, unlike='object_'):
@@ -50,13 +50,13 @@ def objectDialog(obj=None, unlike='object_'):
         val = field.value()
         if key in ['objectColor', 'objectBkColor']:
             #print("VALUE %s" % val)
-            val = GLcolor(val)
+            val = colors.GLcolor(val)
         print("%s: %s = %s" % (actor.name, key, val))
         setattr(actor, key, val)
         pf.canvas.update()
 
     def objectItems(obj):
-        if not isinstance(obj, GeomActor):
+        if not isinstance(obj, Actor):
            return []
 
         items = [
@@ -80,12 +80,12 @@ def objectDialog(obj=None, unlike='object_'):
     if obj is None:
         obj = pf.canvas.actors
 
-    if isinstance(obj, GeomActor):
+    if isinstance(obj, Actor):
         items = objectItems(obj)
 
     elif isinstance(obj, list):
         print([type(o) for o in obj])
-        obj = [o for o in obj if isinstance(o, GeomActor)]
+        obj = [o for o in obj if isinstance(o, Actor)]
         print([o.name for o in obj])
         if unlike:
             obj = [o for o in obj if not o.name.startswith(unlike)]
