@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -31,36 +31,34 @@ the current OpenGL framework in pyFormex.
 (C) 2013 Benedict Verhegghe and the pyFormex project.
 
 """
+import numpy as np
 
 import pyformex as pf
 from pyformex.attributes import Attributes
-from pyformex.opengl.matrix import Matrix4
-from pyformex.opengl.camera import orthogonal_matrix
-from pyformex.opengl.shader import Shader
+from .matrix import Matrix4
+from .camera import orthogonal_matrix
+from .gl import GL
 
-import numpy as np
-from OpenGL import GL
+if not pf.sphinx and pf.options.gl3:
+    from opengl3.shader import Shader
+else:
+    from .shader import Shader
 
 
 class Renderer(object):
 
     def __init__(self, canvas, shader=None):
         self.canvas = canvas
-        self.camera = canvas.camera
-        self.canvas.makeCurrent()
-
         if shader is None:
-            shader = Shader()
+            shader = Shader(self.canvas)
         self.shader = shader
+        self.camera = self.canvas.camera
 
 
     def loadLightProfile(self):
         lightprof = self.canvas.lightprof
         mat = self.canvas.material
-        #print(lightprof)
         lights = [light for light in lightprof.lights if light.enabled]
-        #for light in lights:
-        #    print(light)
         nlights = len(lights)
         ambient = lightprof.ambient * np.ones(3)  # global ambient
         for light in lights:
@@ -69,8 +67,6 @@ class Renderer(object):
         diffuse = np.array([light.diffuse for light in lights]).ravel()
         specular = np.array([light.specular for light in lights]).ravel()
         position = np.array([light.position[:3] for light in lights]).ravel()
-        #print("diffcolor = %s" % diffuse)
-        #print("lightdir = %s" % position)
         settings = Attributes({
             'nlights': nlights,
             'ambicolor': ambient,
@@ -85,7 +81,8 @@ class Renderer(object):
             'alpha': self.canvas.settings.transparency,
             'bkalpha': self.canvas.settings.transparency,
             })
-        #print("LIGHT PROFILE to shader: %s" % settings)
+        #if pf.options.gl3:
+            #print("LIGHT PROFILE to shader: %s" % settings)
         self.shader.loadUniforms(settings)
 
 
@@ -100,10 +97,10 @@ class Renderer(object):
         # single statement like
         #   self.shader.loadUniforms(self.canvas.settings)
         #
-        self.shader.uniformInt('highlight', 0)
+        self.shader.uniformInt('highlight', False)
         self.shader.uniformFloat('lighting', self.canvas.settings.lighting)
         self.shader.uniformInt('useObjectColor', 1)
-        self.shader.uniformInt('rgbamode', 0)
+        self.shader.uniformInt('rgbamode', False)
         self.shader.uniformVec3('objectColor', self.canvas.settings.fgcolor)
         self.shader.uniformVec3('objectBkColor', self.canvas.settings.fgcolor)
         self.shader.uniformVec3('highlightColor', self.canvas.settings.slcolor)
@@ -184,7 +181,7 @@ class Renderer(object):
 
         if pick:
             # PICK MODE
-            from pyformex.opengl import camera
+            from .import camera
             pickmat = camera.pick_matrix(*pick)
             self.shader.uniformMat4('pickmat', pickmat.gl())
 
