@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -34,12 +34,11 @@ for use in the opengl rendering functions.
 """
 
 import pyformex as pf
-from pyformex.opengl.colors import GLcolor
+from pyformex import colors
 import pyformex.arraytools as at
 import numpy as np
 
 
-
 ### Sanitize settings ###############################################
 
 def saneFloat(value):
@@ -98,76 +97,49 @@ def saneColor(color=None):
     [[ 0, 0, 255 ]] will be the same as [ 'blue' ], while
     [ 0,0,255 ] would be a color index with 3 values.
 
+    Examples
+    --------
     >>> print(saneColor('red'))
     [ 1.  0.  0.]
-
     >>> print(saneColor('grey90'))
     [ 0.9  0.9  0.9]
+    >>> saneColor(['red', 'green', 'blue'])
+    array([[ 1.,  0.,  0.],
+           [ 0.,  1.,  0.],
+           [ 0.,  0.,  1.]])
+    >>> saneColor([['red', 'green', 'blue'], ['cyan', 'magenta', 'yellow']])
+    array([[[ 1.,  0.,  0.],
+            [ 0.,  1.,  0.],
+            [ 0.,  0.,  1.]],
+           [[ 0.,  1.,  1.],
+            [ 1.,  0.,  1.],
+            [ 1.,  1.,  0.]]])
 
     """
     if color is None:
         # no color: use canvas color
         return None
 
-    # detect color index
-    try:
-        c = np.asarray(color)
-        if c.dtype.kind == 'i':
-            # We have a color index
-            return c
-    except Exception:
-        pass
-
-    # not a color index: it must be colors
-    try:
-        color = GLcolor(color)
-    except ValueError:
-
-        try:
-            color = [GLcolor(co) for co in color]
-        except ValueError:
-            pass
-
-    # Convert to array
-    try:
-        # REMOVED THE SQUEEZE: MAY BREAK SOME THINGS !!!
-        color = np.asarray(color)  # .squeeze()
-        if color.dtype.kind == 'f' and color.shape[-1] == 3 or color.shape[-1] == 4:
-            # Looks like we have a sane color array
-            return color.astype(np.float32)
-    except Exception:
-        pass
-
-    return None
-
-
-def saneColorArray(color, shape):
-    """Makes sure the shape of the color array is compatible with shape.
-
-    Parameters:
-
-    - `color`: set of colors
-    - `shape`: (nelems,nplex) tuple
-
-    A compatible color.shape is equal to shape or has either or both of its
-    dimensions equal to 1.
-    Compatibility is enforced in the following way:
-
-    - if color.shape[1] != nplex and color.shape[1] != 1: take out first
-      plane in direction 1
-    - if color.shape[0] != nelems and color.shape[0] != 1: repeat the plane
-      in direction 0 nelems times
-
-    """
     color = np.asarray(color)
-    if color.ndim == 1:
-        return color
-    if color.ndim == 3:
-        if color.shape[1] > 1 and color.shape[1] != shape[1]:
-            color = color[:, 0]
-    if color.shape[0] > 1 and color.shape[0] != shape[0]:
-        color = np.resize(color, (shape[0], color.shape[1]))
-    return color
+    if color.dtype.kind == 'i':
+        # We have a color index: convert to int32
+        return color.astype(np.int32)
+
+    if color.dtype.kind != 'f':
+        # Convert to colors
+        try:
+            color = at.mapArray(colors.GLcolor, color)
+        except Exception:
+            print("Could not convert input to colors:")
+            print(color)
+            return None
+
+    if color.shape[-1] == 3 or color.shape[-1] == 4:
+        # Looks like we have a sane color array
+        return color.astype(np.float32)
+
+    print(f"Invalid color array shape: color.shape")
+    return None
 
 
 def saneColorSet(color=None, colormap=None, shape=(1,)):
@@ -186,16 +158,31 @@ def saneColorSet(color=None, colormap=None, shape=(1,)):
         shape = (shape,)
     color = saneColor(color)
     if color is not None:
-        pf.debug("SANECOLORSET: color %s, shape %s" % (color.shape, shape), pf.DEBUG.DRAW)
+        pf.debug(f"SANECOLORSET: color {color.shape}, shape {shape}",
+                 pf.DEBUG.DRAW)
         if color.dtype.kind == 'i':
             ncolors = color.max()+1
+            #print(f"ncolors: {ncolors}")
             if colormap is None:
                 colormap = pf.canvas.settings.colormap
             colormap = saneColor(colormap)
-            colormap = saneColorArray(colormap, (ncolors,))
+            #print(f"Before resize: {colormap.shape}")
+            colormap = at.resizeArray(colormap, (ncolors,colormap.shape[1]))
+            #print(f"After resize: {colormap.shape}")
+            if color.ndim > 1:
+                #print(f"Before resize: {color.shape}")
+                #print(color)
+                color = at.resizeArray(color, shape[:-1])
+                #print(f"After resize: {color.shape}")
+                #print(color)
         else:
-            color = saneColorArray(color, shape)
             colormap = None
+            if color.ndim > 1:
+                #print(f"Before resize: {color.shape}")
+                if color.ndim == 2:
+                    color = at.addAxis(color, 1)
+                color = at.resizeArray(color, shape)
+                #print(f"After resize: {color.shape}")
 
         pf.debug("SANECOLORSET RESULT: %s" % str(color.shape), pf.DEBUG.DRAW)
     return color, colormap
