@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -33,22 +33,21 @@ and its data onto the graphics system.
 
 """
 
-from OpenGL import GL
-from OpenGL.GL import shaders
 import pyformex as pf
+from pyformex.software import SaneVersion
+from pyformex.gui import qtgl
+from . import gl
+from .gl import GL, shaders
 
 
 def defaultShaders():
     """Determine the default shader programs"""
-    from pyformex.opengl import canvas
-    from pyformex.gui import viewport
-    from pyformex.software import SaneVersion
-    glversion = canvas.glVersion()
+    glversion = gl.gl_version()
     vendor = glversion['vendor']
     renderer = glversion['renderer']
     version = glversion['version']
     vmajor, vminor = version.split('.')[:2]
-    fmt = viewport.opengl_format
+    fmt = qtgl.getOpenGLFormat()
     major, minor = fmt.majorVersion(), fmt.minorVersion()
     availversion = "%s.%s" % (vmajor, vminor)
     activeversion = "%s.%s" % (major, minor)
@@ -60,16 +59,15 @@ def defaultShaders():
     fragmentshader = str(dirname / "fragment_shader")
     if not pf.options.shader:
 
-        if pf.options.opengl is not None:
-            if SaneVersion(pf.options.opengl) >= SaneVersion('3.3'):
-                pf.options.shader = '330'
+        if SaneVersion(pf.cfg['opengl/version']) >= SaneVersion('3.3'):
+            pf.options.shader = '330'
 
         # Default shaders for some hardware
 
         pf.debug("Selecting best default shader", pf.DEBUG.OPENGL)
 
-        if 'Mesa' in renderer or 'Mesa' in version:
-            pf.options.shader = 'mesa'
+        #if 'Mesa' in renderer or 'Mesa' in version:
+        #    pf.options.shader = 'mesa'
 
         # For Radeon, select 330 if available
         if 'Radeon' in renderer and SaneVersion(availversion) >= SaneVersion('3.3'):
@@ -81,6 +79,7 @@ def defaultShaders():
         fragmentshader += '_%s' % pf.options.shader
     vertexshader += '.c'
     fragmentshader += '.c'
+    pf.debug(f"Using shaders {vertexshader} and {fragmentshader}", pf.DEBUG.OPENGL)
     return vertexshader, fragmentshader
 
 
@@ -154,7 +153,7 @@ class Shader(object):
         'picking',
     ]
 
-    def __init__(self, vshader=None, fshader=None, attributes=None, uniforms=None):
+    def __init__(self, canvas, vshader=None, fshader=None, attributes=None, uniforms=None):
         _vertexshader, _fragmentshader = defaultShaders()
         if vshader is None:
             vshader = _vertexshader
