@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,8 +26,6 @@
 This module uses textures on quads to render text on an OpenGL canvas.
 It is dependent on freetype and the Python bindings freetype-py.
 """
-
-from OpenGL import GL
 import numpy as np
 
 import pyformex as pf
@@ -37,8 +35,9 @@ from pyformex import freetype as ft
 from pyformex import arraytools as at
 from pyformex.coords import Coords
 from pyformex.formex import Formex
-from pyformex.opengl.drawable import Actor
-from pyformex.opengl.texture import Texture
+from .drawable import Actor
+from .texture import Texture
+from .gl import GL
 from pyformex.plugins.imagearray import array2image, image2array
 
 __all__ = ['FontTexture', 'Text', 'TextArray', 'Mark']
