@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -56,55 +56,52 @@ def createParser():
         # usage = "%(prog)s [<options>] [ [ scriptname [scriptargs] ] ...]",
         description=pf.Description,
         epilog="More info on http://pyformex.org",
-        # formatter = optparse.TitledHelpFormatter(),
+        #formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         add_help=False,  # Because we do not want to exit here on help!
     )
-    MO = parser.add_argument  # create a shorthand notation
-    MO(
-        '-h',
-        "--help",
-        action="store_true",
-        dest="help",
-        default=False,
-        help="Show this help message and exit",
-    )
-    MO(
-        "--version",
-        action='version',
-        version=pf.fullVersion(),
-        help="Show program's version number and exit",
-    )
+    # String to add to help text to display default
+    def MO(*args, show_default=" (default: %(default)s)", **kargs):
+        """Add_argument with automatic showing of default in the help.
+
+        Showing the default can be suppressed by adding show_default=''
+        """
+        if show_default and 'help' in kargs and 'default' in kargs:
+            kargs['help'] += show_default
+        parser.add_argument(*args, **kargs)
+
     MO(
         '-v',
         "--verbose",
         action='store',
         type=int,
         default=2,
-        help="Set the verbosity level (0..5). Default is 2.",
+        help="Set the verbosity level (0..5).",
     )
     MO(
         "--gui",
         action="store_true",
-        dest="gui",
         default=None,
-        help="Start the GUI "
-        "(this is the default when no scriptname argument is given)",
+        help="Start the GUI. This is the default when no FILE "
+        "argument is given.",
+        show_default=False,
     )
     MO(
         "--nogui",
         action="store_false",
         dest="gui",
-        default=None,
-        help="Do not start the GUI "
-        "(this is the default when a scriptname argument is given)",
+        help="Do not start the GUI. This is the default when a FILE "
+        "argument is given.",
+        show_default=False,
     )
     MO(
-        "--nocanvas",
-        action="store_false",
-        dest="canvas",
-        default=True,
-        help="Do not add an OpenGL canvas to the GUI "
-        "(use for development purposes only!)",
+        '-c',
+        "--script",
+        action="store",
+        default=None,
+        metavar='SCRIPT',
+        help="A pyFormex script to be executed at startup. It is executed "
+        "before any specified script files. This is mostly used in --nogui "
+        "mode, when the script to be executed is very short.",
     )
     MO(
         "--interactive",
@@ -112,14 +109,15 @@ def createParser():
         dest="interactive",
         default=False,
         help="Go into interactive mode after processing the command line "
-        "parameters. This is implied by the --gui option.",
+        "parameters. This is implied by the --gui option and defaults to "
+        "False with the --nogui option.",
     )
     MO(
         "--uselib",
         action="store_true",
-        dest="uselib",
         default=None,
         help="Use the pyFormex C lib if available. This is the default.",
+        show_default=False,
     )
     MO(
         "--nouselib",
@@ -127,11 +125,11 @@ def createParser():
         dest="uselib",
         default=None,
         help="Do not use the pyFormex C-lib.",
+        show_default=False,
     )
     MO(
         "--config",
         action="store",
-        dest="config",
         default=None,
         help="Use file CONFIG for settings. This file is loaded in addition "
         "to the normal configuration files and overwrites their settings. "
@@ -140,7 +138,6 @@ def createParser():
     MO(
         "--nodefaultconfig",
         action="store_true",
-        dest="nodefaultconfig",
         default=False,
         help="Skip the default site and user config files. This option can "
         "only be used in conjunction with the --config option.",
@@ -148,31 +145,30 @@ def createParser():
     MO(
         "--redirect",
         action="store_true",
-        dest="redirect",
         default=None,
         help="Redirect standard output to the message board "
         "(ignored with --nogui)",
+        show_default=False,
     )
     MO(
         "--noredirect",
         action="store_false",
         dest="redirect",
         help="Do not redirect standard output to the message board.",
+        show_default=False,
     )
     MO(
         "--debug",
         action="store",
-        dest="debug",
-        default='',
+        default=None,
         help="Display debugging information to sys.stdout. The value is "
         "a comma-separated list of (case-insensitive) debug items. "
-        "Use option --debugitems to list  them. The special value 'all' "
-        "can be used to switch on all debug info.",
+        "Do 'pyformex --debugitems' to get a list of available items. "
+        "The special value 'all' can be used to switch on all debug info.",
     )
     MO(
         "--debuglevel",
         action="store",
-        dest="debuglevel",
         type=int,
         default=0,
         help="Display debugging info to sys.stdout. "
@@ -183,15 +179,13 @@ def createParser():
     MO(
         "--debugitems",
         action="store_true",
-        dest="debugitems",
         default=False,
-        help="Show all available debug items. "
-        "Each of these can be used with the -debug option.",
+        help="Show all available debug items and exit",
+        show_default=False,
     )
     MO(
         "--mesa",
         action="store_true",
-        dest="mesa",
         default=False,
         help="Force the use of software 3D rendering through the mesa libs. "
         "The default is to use hardware accelerated rendering whenever "
@@ -202,10 +196,10 @@ def createParser():
     MO(
         "--dri",
         action="store_true",
-        dest="dri",
         default=None,
         help="Use Direct Rendering Infrastructure. "
         "By default, direct rendering will be used if available.",
+        show_default=False,
     )
     MO(
         "--nodri",
@@ -215,20 +209,35 @@ def createParser():
         help="Do not use the Direct Rendering Infrastructure. "
         "This may be used to turn off the direc rendering, e.g. to allow "
         "better capturing of images and movies.",
+        show_default=False,
+    )
+    MO(
+        "--gl3",
+        action="store_true",
+        default=False,
+        help="Use the new development gl3 engine. "
+        "Note: this is for developers only. Most drawing functions will not "
+        "work if you use this.",
+    )
+    MO(
+        "--mgl",
+        action="store_true",
+        default=False,
+        help="Use moderngl instead of PyOpenGL. "
+        "Note: this is for developers only. Most drawing functions will not "
+        "work if you use this.",
     )
     MO(
         "--opengl",
         action="store",
-        dest="opengl",
         default='2.0',
         help="Force the use of a specific OpenGL version. "
-        "The version should be specified as a string 'a.b'. The default is 2.0",
+        "The version should be specified as a string 'a.b'.",
     )
     MO(
         "--shader",
         action="store",
-        dest="shader",
-        default='',
+        default='130',
         help="Force the use of an alternate GPU shader for the OpenGL "
         "rendering. If the default selected shader does not work well "
         "for your hardware, you can use this option to try one of the "
@@ -242,10 +251,25 @@ def createParser():
         default=True,
         help="Switch off the use of multisample buffers in OpenGL.",
     )
+    MO(
+        "--fixcbo",
+        action="store_true",
+        default=False,
+        help="Switch a bug on some graphics cards.",
+    )
+    MO(
+        "--bindings",
+        action="store",
+        default=None,
+        help="Override the configuration setting for the Qt5/4 bindings. "
+        "Available bindings are 'pyside2' or 'pyqt5' for Qt5 and "
+        "'pyside' or 'pyqt4' for Qt4. "
+        "A value 'any' may be given to let pyFormex find out which "
+        "bindings are available and use one of these.",
+    )
     MO(
         "--vtk",
         action="store",
-        dest="vtk",
         default='default',
         help="Specify which version of python-vtk to use in vtk_itf plugin. "
         "The value can be one of: 'standard', 'light', or 'default'. "
@@ -255,62 +279,47 @@ def createParser():
     MO(
         "--testcamera",
         action="store_true",
-        dest="testcamera",
         default=False,
         help="Print camera settings whenever they change.",
     )
     MO(
         "--memtrack",
         action="store_true",
-        dest="memtrack",
         default=False,
         help="Track memory for leaks. This is only for developers.",
     )
-    MO(
-        "--fastnurbs",
-        action="store_true",
-        dest="fastnurbs",
-        default=False,
-        help="Test C library nurbs drawing: only for developers!",
-    )
-    MO(
-        "--pathlib",
-        action="store_true",
-        dest="pathlib",
-        default=False,
-        help="Use the Python3 pathlib library. "
-        "Use only for development and testing purposes.",
-    )
-    MO(
-        "--bindings",
-        action="store",
-        dest="bindings",
-        default=None,
-        help="Override the configuration setting for the Qt5/4 bindings. "
-        "Available bindings are 'pyside2' or 'pyqt5' for Qt5 and "
-        "'pyside' or 'pyqt4' for Qt4. "
-        "A value 'any' may be given to let pyFormex find out which "
-        "bindings are available and use one of these.",
-    )
+    # MO(
+    #     "--fastnurbs",
+    #     action="store_true",
+    #     default=False,
+    #     help="Test C library nurbs drawing: only for developers!",
+    # )
     MO(
         "--experimental",
         action="store_true",
-        dest="experimental",
         default=False,
         help="Allow the pyformex/experimental modules to be loaded. "
         "Beware: use only if you know what you are doing!",
     )
+    MO(
+        "--nocanvas",
+        action="store_false",
+        dest="canvas",
+        default=True,
+        help="Do not add an OpenGL canvas to the GUI "
+        "(use for development purposes only!)",
+        show_default=False,
+    )
     MO(
         "--listfiles",
         action="store_true",
-        dest="listfiles",
         default=False,
         help="List the pyFormex Python source files and exit.",
+        show_default=False,
     )
     MO(
         "--listmodules",
         action="store",
-        dest="listmodules",
         default=None,
         metavar='PKG',
         nargs='*',
@@ -318,11 +327,11 @@ def createParser():
         "and exit. Specify 'core' to just list the modules in the pyFormex "
         "top level. Specify 'all' to list all modules. The default is to "
         "list the modules in core, lib, plugins, gui, opengl.",
+        show_default=False,
     )
     MO(
         "--search",
         action="store_true",
-        dest="search",
         default=False,
         help="Search the pyformex source for a specified pattern and exit. "
         "This can optionally be followed by -- followed by options for the "
@@ -330,11 +339,11 @@ def createParser():
         "path. The final argument is the pattern to search. '-e' before the "
         "pattern will interprete this as an extended regular expression. '-l' "
         "option only lists the names of the matching files.",
+        show_default=False,
     )
     MO(
         "--remove",
         action="store_true",
-        dest="remove",
         default=False,
         help="Remove the pyFormex installation and exit. This option only "
         "works when pyFormex was installed from a tarball release using the "
@@ -342,47 +351,47 @@ def createParser():
         "package (e.g. Debian), you should use your distribution's package "
         "tools to remove pyFormex. If you run pyFormex directly from the git "
         "source, you should just remove the whole cloned source tree.",
+        show_default=False,
     )
     MO(
         "--whereami",
         action="store_true",
-        dest="whereami",
         default=False,
         help="Show where the pyformex package is installed and exit.",
+        show_default=False,
     )
     MO(
         "--detect",
         action="store_true",
-        dest="detect",
         default=False,
         help="Show detected helper software and exit.",
+        show_default=False,
     )
     MO(
         "--doctest",
         action="store",
-        dest="doctest",
         default=None,
         metavar='MODULE',
         nargs='*',
         help="Run the docstring tests for the specified pyFormex modules "
         "and exit. MODULE name is specified in Python syntax, relative "
         "to the pyformex package (e.g. coords, plugins.curve).",
+        show_default=False,
     )
     MO(
         "--pytest",
         action="store",
-        dest="pytest",
         default=None,
         metavar='MODULE',
         nargs='*',
         help="Run the pytest tests for the specified pyFormex modules "
         "and exit. MODULE name is specified in Python syntax, relative "
         "to the pyformex package (e.g. coords, plugins.curve).",
+        show_default=False,
     )
     MO(
         "--docmodule",
         action="store",
-        dest="docmodule",
         default=None,
         metavar='MODULE',
         nargs='*',
@@ -391,27 +400,46 @@ def createParser():
         "pyFormex reference manual, as the produced result still needs "
         "to be run through the Sphinx documentation generator. MODULE "
         "is the name of a pyFormex module (Python syntax).",
+        show_default=False,
     )
     MO(
-        '-c',
-        "--script",
+        "--runall",
         action="store",
-        dest="script",
-        default=None,
-        metavar='SCRIPT',
-        help="A pyFormex script to be executed at startup. It is executed "
-        "before any specified script files. This is mostly used in --nogui "
-        "mode, when the script to execute is very short.",
+        type=int,
+        metavar='COUNT',
+        help="Automatically run some random examples at startup. Specify "
+        "the number of examples, or -1 for all examples (may take a while).",
+    )
+    MO(
+        "--version",
+        action='version',
+        version=pf.fullVersion(),
+        help="Show program's version number and exit",
+    )
+    MO(
+        '-h',
+        "--help",
+        action="store_true",
+        default=False,
+        help="Show this help message and exit",
+        show_default=False,
     )
     MO(
         "args",
         action="store",
         nargs='*',
-        metavar='FILE',
-        help="pyFormex script files to be executed on startup. The files "
-        "should have a .py extension. Their contents will be executed as "
-        "a pyFormex script. While mostly used with the --nogui option, "
-        "this will also work in GUI mode.",
+        metavar='FILE/APP [ARGS ... [++]]',
+        help="pyFormex script file or app to be executed on startup. "
+        "If it is a filename, it should have a .py suffix and the contents "
+        "will be executed in script mode. Else, it is an app in Python "
+        "pkg.module notation, and it should be located under one of the "
+        "application paths specified in the 'appsdirs' configuration "
+        "variable. In both cases the arguments following FILE/APP will be "
+        "available to the script/app in a global variable ``_argv_``. "
+        "A '++' in the ARGS list ends the argument list for the script/app, "
+        "and the next argument will again be interpreted as a FILE/APP. "
+        "FILE/APP arguments are mostly used in --nogui mode but also work "
+        "in GUI mode.",
     )
 
     return parser
