@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -1036,14 +1036,12 @@ class Path(str):
         [Path('/etc/init.d')]
         >>> Path('pyformex/pr*.py').glob()
         [Path('pyformex/process.py'), Path('pyformex/project.py')]
-        >>> Path('pyformex/**/pa*.py').glob()
+        >>> Path('**/pa*.py').glob()
+        [Path('pyformex/path.py')]
+        >>> Path('pyformex/**/pa*t*.py').glob()
         [Path('pyformex/plugins/partition.py')]
-        >>> Path('pyformex/**/pa*.py').glob(recursive=True)
+        >>> Path('pyformex/**/pa*t*.py').glob(recursive=True)
         [Path('pyformex/path.py'), Path('pyformex/plugins/partition.py')]
-        >>> Path('**/q*.py').glob()
-        []
-        >>> Path('pyformex/*/q*.py').glob(recursive=True)
-        [Path('pyformex/gui/qtutils.py')]
         """
         import glob
         return sorted([Path(i) for i in glob.glob(self, recursive=recursive)])
