@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -189,7 +189,7 @@ def exportDxfText():
     parts = named('_dxf_sel_')
     if parts:
         cur = pf.cfg['workdir']
-        fn = askFilename(cur=cur, filter='dxftext', exist=False)
+        fn = askFilename(cur=cur, filter='dxftext')
         if fn:
             dxf.exportDxfText(fn, parts)
             print("Wrote .dxftext file %s" % fn)
@@ -204,7 +204,7 @@ def exportDxf():
     parts = named('_dxf_sel_')
     if parts:
         cur = pf.cfg['workdir']
-        fn = askFilename(cur=cur, filter='dxf', exist=False)
+        fn = askFilename(cur=cur, filter='dxf')
         if fn:
             dxf.exportDxf(fn, parts)
 
@@ -214,7 +214,7 @@ def exportDxf():
 ##     F = named("_lines_")
 ##     if F:
 ##         cur = pf.cfg['workdir']
-##         fn = askFilename(cur=cur,filter='dxf',exist=False)
+##         fn = askFilename(cur=cur,filter='dxf')
 ##         if fn:
 ##             dxf.exportDXF(fn,F)
 ##             print("Wrote .dxf file %s" % fn)
