@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -79,8 +79,8 @@ class FeResult(object):
     """
 
     _name_ = '__FePost__'
-    re_Skey = re.compile("S[0-5]")
-    re_Ukey = re.compile("U[0-2]")
+    re_Skey = re.compile(r"S[0-5]")
+    re_Ukey = re.compile(r"U[0-2]")
 
     def __init__(self, name=_name_, datasize={'U': 3, 'S': 6, 'COORD': 3}):
         self.name = name
