@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -201,7 +201,7 @@ def importGeometry(select=True, draw=True, ftype=None, compr=False):
     If select and draw are True (default), the selection is drawn.
     """
     if ftype is None:
-        ftype = ['pgf', 'pyf', 'pzf', 'surface', 'poly', 'obj', 'ply', 'off', 'stl', 'gts', 'smesh', 'neu', 'inp', 'all']
+        ftype = ['pgf', 'pyf', 'pzf', 'surface', 'poly', 'off', 'stl', 'gts', 'smesh', 'neu', 'inp', 'all']
     elif isinstance(ftype, list):
         pass
     else:
@@ -209,13 +209,13 @@ def importGeometry(select=True, draw=True, ftype=None, compr=False):
     cur = pf.cfg['workdir']
     #fn = askFilename(cur=cur, filter=ftype, compr=compr)
     from pyformex.gui.dialogs import FileDialog
-    print(ftype)
+    #print(ftype)
     if ftype == ['poly']:
         extra = [_I('mplex', 4)]
     else:
         extra = []
-    print(extra)
-    dia = FileDialog(filter=ftype, extra=extra)
+    #print(extra)
+    dia = FileDialog(filter=ftype, mode='exist', extra=extra, compr=compr)
     res = dia.getResults()
     if res:
         print("Reading geometry file %s" % res['filename'])
@@ -246,6 +246,9 @@ def importPzf(_canvas=True, _camera=True):
             settings = res['_canvas']
             pf.GUI.viewports.loadConfig(settings)
             pf.GUI.viewports.update()
+            # TODO: this is needed to update the camera. Not sure why:
+            # isn't this included in viewports.update ???
+            pf.canvas.update()
     elif '_camera' in res:
         if _camera or ack("The PZF file contains camera settings.\nDo you want to apply them?"):
             settings = res['_camera']
@@ -283,7 +286,7 @@ def importModel(*filenames):
     If none is given, the user will be asaked.
     """
     if not filenames:
-        filenames = askFilename(".", "*.mesh", multi=True)
+        filenames = askFilename(".", "*.mesh", mode='multi')
         if not filenames:
             return
 
@@ -303,7 +306,7 @@ def readInp(fn=None):
 
     """
     if fn is None:
-        fn = askFilename(".", "*.inp", multi=True)
+        fn = askFilename(".", "*.inp", mode='multi')
         if not fn:
             return
 
@@ -358,7 +361,8 @@ def writeGeometry(obj, filename, ftype=None, compr=False, **kargs):
             elif ftype in utils.fileTypes('off', compr=compr):
                 filewrite.writeOFF(filename, mesh)
             elif ftype in utils.fileTypes('ply', compr=compr):
-                filewrite.writePLY(filename, mesh)
+                filewrite.writePLY(filename, mesh.coords,
+                                   {mesh.nplex():mesh.elems})
             nobj += 1
 
     else:
@@ -383,11 +387,12 @@ def exportGeometry(ftype, single=False, compr=True, **kargs):
         return
 
     cur = pf.cfg['workdir']
-    res = askFile(cur=cur, filter=ftype, exist=False, compr=compr, **kargs)
+    res = askFile(cur=cur, filter=ftype, compr=compr, **kargs)
     if res:
-        fn = res['fn']
-        del res['fn']
+        fn = res['filename']
+        del res['filename']
         print(f"Writing geometry file {fn}")
+        print(res)
         res = writeGeometry(db.odict(), fn, compr=compr, **res)
         print(f"Contents: {res}")
 
@@ -396,7 +401,7 @@ def exportPgf():
     kargs = {
         'compr': True,
         'compression': 4,
-        'mode': 'binary',
+        'fmode': 'binary',
     }
     exportGeometry('pgf', single=False, **kargs)
 
@@ -1234,8 +1239,7 @@ def create_menu():
             (utils.fileDescription('pgf').replace('g', '&g'), exportPgf),
             (utils.fileDescription('off').replace('ob', '&ob'), exportOff),
             (utils.fileDescription('obj'), exportObj),
-        # commented out because currently broken
-        #   (utils.fileDescription('ply'), exportPly),
+            (utils.fileDescription('ply'), exportPly),
             ]),
         ("&Select ", [
             ('Any', set_selection),
