@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,8 +27,7 @@ import numpy as np
 import pyformex as pf
 from pyformex import formex
 
-
-from PySide2.QtCore import Qt, QThread
+from pyformex.gui import QtCore
 from OpenGL.arrays import vbo
 
 
@@ -78,13 +77,13 @@ class Manipulator:
         setattr(self.actor, 'highlighting', None)
 
         # Start loop of events
-        self.canvas.setMouse(Qt.LeftButton, self.left_mouse_button)
-        self.canvas.setMouse(Qt.RightButton, self.canvas.emit_done)
-        self.canvas.DONE.connect(self.stop)
+        self.canvas.setMouse(QtCore.Qt.LeftButton, self.left_mouse_button)
+        self.canvas.setMouse(QtCore.Qt.RightButton, self.canvas.emit_done)
+        self.canvas.signals.DONE.connect(self.stop)
 
         self.canvas.adjust_busy = True
 
-        timer = QThread()
+        timer = QtCore.QThread()
         while self.canvas.adjust_busy:
 
             timer.msleep(10)
