@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,10 +29,8 @@ import pyformex as pf
 from pyformex import utils
 from pyformex.gui import menu
 
-from numpy import *
 from pyformex.lazy import *
 from pyformex.gui.draw import *
-from pyformex.opengl.colors import *
 
 
 def about():
@@ -263,7 +261,7 @@ def runLocalProcessor(filename='', processor='abaqus'):
     if filename:
         filename = Path(filename)
     else:
-        filename = askFilename(pf.cfg['workdir'], filter="Abaqus input files (*.inp)", exist=True)
+        filename = askFilename(pf.cfg['workdir'], filter="Abaqus input files (*.inp)", mode='exist')
     cpus = '6'
     if filename:
         jobname = filename.stem
@@ -288,7 +286,7 @@ def submitToCluster(filename=None):
     if filename:
         filename = Path(filename)
     else:
-        filename = askFilename(pf.cfg['workdir'], filter="Abaqus input files (*.inp)", exist=True)
+        filename = askFilename(pf.cfg['workdir'], filter="Abaqus input files (*.inp)", mode='exist')
     if filename:
         jobname = filename.stem
         dirname = filename.parent
