@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,11 +29,11 @@ import numpy
 
 import pyformex as pf
 from pyformex import Path
-from pyformex.opengl import colors
+from pyformex import colors
+from pyformex import geomtools
 from pyformex.opengl import decors
 from pyformex.gui.draw import *
 from pyformex.lazy import *
-from pyformex import geomtools
 
 inverse = numpy.linalg.linalg.inv
 
@@ -132,11 +132,11 @@ def partition(Fin, prop=0):
     if prop is None or prop < 0:
         prop = 0
 
-    # Make sure the inital Formex is centered
+    # Make sure the initial Formex is centered
     initial_trl = -Fin.center()
     F = Fin.translate(initial_trl)
 
-    # Store the inital properties and make all properties equal to start value
+    # Store the initial properties and make all properties equal to start value
     initial_prop = F.prop
     F.setProp(prop)
 
