@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -111,12 +111,13 @@ def read_Surface(fn, exportName=True):
 
 
 def readSelection(select=True, draw=True, multi=True):
-    """Read a Surface (or list) from asked file name(s).
+    """Read one or more Surface(s) from asked file name(s).
 
     If select is True (default), this becomes the current selection.
     If select and draw are True (default), the selection is drawn.
     """
-    fn = askFilename(pf.cfg['workdir'], ['surface', 'all'], multi=multi)
+    mode = 'multi' if multi else 'exist'
+    fn = askFilename(pf.cfg['workdir'], ['surface', 'all'], mode=mode)
     if fn:
         if not multi:
             fn = [fn]
@@ -377,7 +378,7 @@ def export_stl():
         fn = Path(res['filename'])
         ftype = fn.ftype
         if res['binary']:
-            from pyformex.opengl import colors
+            from pyformex import colors
             ftype = 'stlb'
             color = colors.RGBAcolor(res['color'], res['alpha'])
         else:
