@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -76,7 +76,7 @@ def command():
 
 
 def dos2unix():
-    fn = askFilename(multi=True)
+    fn = askFilename(mode='multi')
     if fn:
         for f in fn:
             print("Converting file to UNIX: %s" % f)
@@ -84,7 +84,7 @@ def dos2unix():
 
 
 def unix2dos():
-    fn = askFilename(multi=True)
+    fn = askFilename(mode='multi')
     if fn:
         for f in fn:
             print("Converting file to DOS: %s" % f)
