@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -38,7 +38,7 @@ import numpy as np
 import pyformex as pf
 from pyformex import utils
 from pyformex import Path
-from pyformex.opengl import colors
+from pyformex import colors
 from pyformex.olist import List, intersection
 from pyformex.mydict import Dict
 from pyformex.arraytools import checkFloat, checkArray, checkInt
@@ -693,7 +693,7 @@ def surface2webgl(S, name, caption=None):
 def createMultiWebGL():
     """Creates a multimodel WebGL from single WebGL models"""
     from pyformex.gui.draw import askFilename, askNewFilename, ack, showHTML
-    models = askFilename(filter=['html', 'js'], multi=True)
+    models = askFilename(filter=['html', 'js'], mode='multi')
     if not models:
         return
     combined = askNewFilename(filter=['html', 'js'], caption="Enter name of the combined model")
