@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -146,79 +146,87 @@ class Project(TrackedDict):
        this uses a stable ascii based format. It can however (currently) only
        store obects of class Geometry or one of its subclasses.
 
-    Parameters:
+    Parameters
+    ----------
+    filename: :term:`path_like`
+        The name of the file where the Project data will be saved.
+        If the file exists (and `access` is not `w`), it should be a previously
+        saved Project and an attempt will be made to load the data from this
+        file into the Project. If this fails, an error is raised.
 
-    - `filename`: the name of the file where the Project data will be saved.
-      If the file exists (and `access` is not `w`), it should be a previously
-      saved Project and an attempt will be made to load the data from this
-      file into the Project.
-      If this fails, an error is raised.
+        If the file exists and `access` is `w`, it will be overwritten,
+        destroying any previous contents.
 
-      If the file exists and `access` is `w`, it will be overwritten,
-      destroying any previous contents.
+        If no filename is specified, a temporary file will be created when
+        the Project is saved for the first time. The file with not be
+        automatically deleted. The generated name can be retrieved from the
+        filename attribute.
 
-      If no filename is specified, a temporary file will be created when
-      the Project is saved for the first time. The file with not be
-      automatically deleted. The generated name can be retrieved from the
-      filename attribute.
+    access: str, optional
+        The access mode of the project file: 'wr' (default), 'rw', 'w' or 'r'.
+        If the string contains an 'r' the data from an existing file will be
+        read into the Project. If the string starts with an 'r', the file should
+        exist. If the string contains a 'w', the data can be written back to
+        the file. The 'r' access mode is a read-only mode.
 
-    - `access`: One of 'wr' (default), 'rw', 'w' or 'r'.
-      If the string contains an 'r' the data from an existing file will be
-      read into the dict. If the string starts with an 'r', the file should
-      exist. If the string contains a 'w', the data can be written back to
-      the file. The 'r' access mode is thus a read-only mode.
+        ======  ===============  ============  ===================
+        access  File must exist  File is read  File can be written
+        ======  ===============  ============  ===================
+          r           yes             yes             no
+          rw          yes             yes             yes
+          wr          no         if it exists         yes
+          w           no              no              yes
+        ======  ===============  ============  ===================
 
-      ======  ===============  ============  ===================
-      access  File must exist  File is read  File can be written
-      ======  ===============  ============  ===================
-        r           yes             yes             no
-        rw          yes             yes             yes
-        wr          no         if it exists         yes
-        w           no              no              yes
-      ======  ===============  ============  ===================
+    convert: bool, optional
+        If True (default), and the file is opened for reading, an
+        attempt is made to open old projects in a compatibility mode, doing the
+        necessary conversions to new data formats. If convert is set to False,
+        only the latest format can be read and older formats will generate
+        an error.
 
-    - `convert`: if True (default), and the file is opened for reading, an
-      attempt is made to open old projects in a compatibility mode, doing the
-      necessary conversions to new data formats. If convert is set False,
-      only the latest format can be read and older formats will generate
-      an error.
+    signature: str, optional
+        A text that will be written in the header record of the
+        file. This can e.g. be used to record format version info.
 
-    - `signature`: A text that will be written in the header record of the
-      file. This can e.g. be used to record format version info.
+    compression: int (0-9)
+        The compression level. For large data sets, compression leads
+        to much smaller files. 0 is no compression, 9 is maximal compression.
+        The default is 4.
 
-    - `compression`: An integer from 0 to 9: compression level. For large
-      data sets, compression leads to much smaller files. 0 is no compression,
-      9 is maximal compression. The default is 4.
+    binary: bool
+        If False and no compression is used, storage is done
+        in an ASCII format, allowing to edit the file. Otherwise, storage
+        uses a binary format. Using binary=False is deprecated.
 
-    - `binary`: if False and no compression is used, storage is done
-      in an ASCII format, allowing to edit the file. Otherwise, storage
-      uses a binary format. Using binary=False is deprecated.
+    data: dict, optional
+        A dict-like object to initialize the Project contents. These data
+        may override values read from the file.
 
-    - `data`: a dict-like object to initialize the Project contents. These data
-      may override values read from the file.
-
-    Example:
-
-      >>> d = dict(a=1,b=2,c=3,d=[1,2,3],e={'f':4,'g':5})
-      >>> P = Project()
-      >>> P.update(d)
-      >>> print(P)
-      Project name: None
-        access: wr    mode: b     gzip: 5
-        signature: pyFormex ...
-        contents: ['a', 'b', 'c', 'd', 'e']
-      <BLANKLINE>
-      >>> print(utils.dictStr(P))
-      {'a': 1, 'b': 2, 'c': 3, 'd': [1, 2, 3], 'e': ...}
-      >>> with utils.TempFile() as tmp:
-      ...     P.save(filename=tmp.path, quiet=True)
-      ...     P.clear()
-      ...     print(utils.dictStr(P))
-      ...     P.load(quiet=True)
-      {}
-      >>> print(utils.dictStr(P))
-      {'a': 1, 'b': 2, 'c': 3, 'd': [1, 2, 3], 'e': ...}
+    protocol: int,optional
+        The protocol to be used in pickling the data to file. If not specified,
+        the highest protocol supported by the pickle module is used.
 
+    Examples
+    --------
+    >>> d = dict(a=1,b=2,c=3,d=[1,2,3],e={'f':4,'g':5})
+    >>> P = Project()
+    >>> P.update(d)
+    >>> print(P)
+    Project name: None
+      access: wr    mode: b     gzip: 5
+      signature: pyFormex ...
+      contents: ['a', 'b', 'c', 'd', 'e']
+    >>> print(repr(P))
+    {'a': 1, 'b': 2, 'c': 3, 'd': [1, 2, 3], 'e': ...}
+    >>> with utils.TempFile() as tmp:
+    ...     P.save(filename=tmp.path, quiet=True)
+    ...     P.clear()
+    ...     print(repr(P))
+    ...     P.load(quiet=True)
+    {}
+    >>> print(repr(P))
+    {'a': 1, 'b': 2, 'c': 3, 'd': [1, 2, 3], 'e': ...}
     """
 
     # Historically there have been a few different formats of the
@@ -226,16 +234,10 @@ class Project(TrackedDict):
     # version.
     latest_format = 3
 
-
     def __init__(self, filename=None, access='wr', convert=True,
                  signature=_signature_, compression=5, binary=True,
-                 data={}, protocol=default_protocol, **kargs):
+                 data={}, protocol=default_protocol):
         """Create a new project."""
-        if 'create' in kargs:
-            utils.warn("warn_project_create")
-        if 'legacy' in kargs:
-            utils.warn("warn_project_legacy")
-
         self.filename = Path(filename) if filename else None
         self.access = access
         self.signature = str(signature)
