@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -226,27 +226,370 @@ starttime = 0.0
 scriptInit = None  # can be set to execute something before each script
 
 
+def playScript(scr, name=None, filename=None, argv=[], encoding=None):
+    """Run a pyFormex script specified as text.
+
+    Parameters
+    ----------
+    scr: str
+        A multiline string holding a valid Python program, ususally a
+        pyFormex script. The program will be executed in an internal
+        interpreter, with the :func:`Globals` as local definitions.
+        There is a lock to prevent multiple scripts from being executed
+        at the same time. This implies that pyFormex scripts can not
+        start another script.
+    name: str, optional
+        If specified, this name is set in the global variable pf.scriptName
+        to identify the currently running script.
+    filename: :term:`path_like`, optional
+        If specified, this filename is set into the global variable __file__
+        in the script executing environment.
+    argv: list, optional
+        This value is set in the global variable _argv_.
+        It is mostly used to pass an argument list to the script in --nogui
+        mode.
+    encoding: str, optional
+        If specified, this is an encoding scheme for the script text provided
+        in ``scr``. The text will be decoded by the specified scheme prior to
+        execution. This is mostly intended to obfuscate the code for
+        occasional viewer.
+    """
+    global starttime
+    global exitrequested
+
+    # (We only allow one script executing at a time!)
+    # and scripts are non-reentrant
+    if len(pf.scriptlock) > 0:
+        print("!!Not executing because a script lock has been set: "
+              f"{pf.scriptlock}")
+        return 1
+
+    scriptLock('__auto/script__')
+    exitrequested = False
+
+    if pf.GUI:
+        pf.GUI.startRun()
+
+    # # Read the script, if a file was specified
+    # if not isinstance(scr, str):
+    #     # scr should be an open file/stream
+    #     if filename is None:
+    #         filename = scr.name
+    #     scr = scr.read() + '\n'
+
+    # Get the globals
+    g = Globals()
+    if filename:
+        g.update({'__file__': filename})
+    g.update({'_argv_': argv})
+
+    # TODO: Should we continue support for this?
+    if encoding=='pye':
+        n = (len(scr)+1) // 2
+        scr = utils.mergeme(scr[:n], scr[n:])
+    elif encoding=='egg':
+        import base64
+        scr = base64.b64decode(scr)
+
+    if isinstance(scr, bytes):
+        scr = scr.decode('utf-8')
+
+    # Now we can execute the script using these collected globals
+    pf.scriptName = name
+    exitall = False
+
+    if pf.debugOn(pf.DEBUG.MEM):  # use a test to avoid evaluation of memUsed
+        memu = utils.memUsed()
+        pf.debug(f"MemUsed = {memu}", pf.DEBUG.MEM)
+
+    if filename is None:
+        filename = '<string>'
+
+    # Execute the code
+    # starttime = time.clock()
+    try:
+        pf.interpreter.locals.update(g)
+        pf.interpreter.runsource(scr, str(filename), 'exec')
+
+    except SystemExit:
+        print("EXIT FROM SCRIPT")
+
+    finally:
+        # honour the exit function
+        if 'atExit' in g:
+            atExit = g['atExit']
+            try:
+                atExit()
+            except Exception:
+                pf.debug('Error while calling script exit function',
+                         pf.DEBUG.SCRIPT)
+
+        if pf.cfg['autoglobals']:
+            if pf.console:
+                g = pf.console.interpreter.locals
+            autoExport(g)
+        scriptRelease('__auto/script__')  # release the lock
+        if pf.GUI:
+            pf.GUI.stopRun()
+
+    if pf.debugOn(pf.DEBUG.MEM):  # use a test to avoid evaluation of memUsed
+        pf.debug(f"MemUsed = {utils.memUsed()}", pf.DEBUG.MEM)
+        pf.debug(f"Diff MemUsed = {utils.memUsed()-memu}; ", pf.DEBUG.MEM)
+
+    if exitall:
+        pf.debug("Calling quit() from playScript", pf.DEBUG.SCRIPT)
+        quit()
+
+    return 0
+
+
+def runScript(fn, argv=[]):
+    """Run a pyFormex script stored on a file.
+
+    Parameters
+    ----------
+    fn: :term:`path_like`
+        The name of a file holding a pyFormex script.
+    argv: list, optional
+        A list of arguments to be passed to the script. This argument list
+        becomes available in the script as the global variable _argv_.
+
+    Notes
+    -----
+    This calls :func:`playScript` to execute the code read from the script file.
+
+    See Also
+    --------
+    runApp: run a pyFormex application
+    runAny: run a pyFormex script or app
+    """
+    fn = Path(fn)
+    from pyformex.timer import Timer
+    t = Timer()
+    msg = f"Running script ({fn})"
+    if pf.GUI:
+        pf.GUI.scripthistory.add(str(fn))
+        pf.GUI.board.write(msg, color='red')
+    else:
+        print(msg)
+    pf.debug(f"  Executing with arguments: {argv}", pf.DEBUG.SCRIPT)
+    encoding = None
+    if fn.suffix == '.pye':
+        encoding = 'pye'
+
+    res = playScript(fn.read_text(), fn, fn, argv, encoding)
+    pf.debug(f"  Arguments left after execution: {argv}", pf.DEBUG.SCRIPT)
+    msg = f"Finished script {fn} in {t.seconds()} seconds"
+    if pf.GUI:
+        pf.GUI.board.write(msg, color='red')
+    else:
+        print(msg)
+    return res
+
+
+def runApp(appname, argv=[], refresh=False, lock=True, check=True, wait=False):
+    """Run a pyFormex application.
+
+    A pyFormex application is a Python module that can be loaded in
+    pyFormex and at least contains a function 'run()'. Running the
+    application means execute this function.
+
+    Parameters
+    ----------
+    appname: str
+        The name of the module in Python dot notation. The module should
+        live in a path included in the 'appsdirs' configuration variable.
+    argv: list, optional
+        A list of arguments to be passed to the app. This argument list
+        becomes available in the app as the global variable _argv_.
+    refresh: bool
+        If True, the app module will be reloaded before running it.
+    lock: bool
+        If True (default), the running of the app will be recorded so that
+        other apps can be locked out while this one has not finished.
+    check: bool
+        If True (default), check that no other app is running at this time.
+        If another app is running, either wait or return without executing.
+    wait: bool
+        If True, and check is True and another app is busy, wait until that
+        one has finished and then start execution.
+
+    Returns
+    -------
+    int
+        The return value of the run function. A zero value is supposed
+        to mean a normal exit.
+
+    See Also
+    --------
+    runScript: run a pyFormex script
+    runAny: run a pyFormex script or app
+    """
+    pf.debug(f"runApp '{appname}'", pf.DEBUG.APPS)
+    global exitrequested
+    if check:
+        while len(pf.scriptlock) > 0:
+            if wait:
+                 print(f"!!Waiting for lock {pf.scriptlock} to be released")
+                 time.sleep(5)
+            else:
+                 print("!!Not executing because a script lock has been set: "
+                       f"{pf.scriptlock}")
+                 return
+
+    from pyformex import apps
+    from pyformex.timer import Timer
+    t = Timer()
+    print(f"Loading application {appname} with refresh={refresh}")
+    app = apps.load(appname, refresh=refresh)
+    if app is None:
+        errmsg = f"An error occurred while loading application {appname}"
+        if apps._traceback and pf.cfg['showapploaderrors']:
+            print(apps._traceback)
+        if pf.GUI:
+            from pyformex.gui import draw
+            fn = apps.findAppSource(appname)
+            if fn.exists():
+                errmsg += ("\n\nYou may try executing the application "
+                           "as a script,\n  or you can load the source "
+                           "file in the editor.")
+                res = draw.ask(errmsg, choices=[
+                    'Run as script', 'Load in editor', "Don't bother"])
+                if res[0] in 'RL':
+                    if res[0] == 'L':
+                        draw.editFile(fn)
+                    elif res[0] == 'R':
+                        pf.GUI.setcurfile(fn)
+                        runScript(fn)
+            else:
+                errmsg += "and I can not find the application source file."
+                draw.error(errmsg)
+        else:
+            error(errmsg)
+
+        return
+
+    if hasattr(app, '_status') and app._status == 'unchecked':
+        pf.warning(
+            "This looks like an Example script that has been automatically "
+            "converted to the pyFormex Application model, but has not been "
+            "checked yet as to whether it is working correctly in App mode.\n"
+            "You can help here by running and rerunning the example, checking "
+            "that it works correctly, and where needed fixing it (or reporting "
+            "the failure to us). If the example runs well, you can change its "
+            "status to 'checked'")
+
+    if lock:
+        scriptLock('__auto/app__')
+    msg = f"Running application '{appname}' from {app.__file__}"
+    pf.scriptName = appname
+    if pf.GUI:
+        pf.GUI.startRun()
+        pf.GUI.apphistory.add(appname)
+        pf.GUI.board.write(msg, color='green')
+    else:
+        print(msg)
+    pf.debug(f"  Passing arguments: {argv}", pf.DEBUG.SCRIPT)
+    app._argv_ = argv
+    try:
+        try:
+            res = app.run()
+        except SystemExit:
+            print("EXIT FROM APP")
+            pass
+        except Exception:
+            raise
+    finally:
+        if hasattr(app, 'atExit'):
+            app.atExit()
+        if pf.cfg['autoglobals']:
+            g = app.__dict__
+            autoExport(g)
+        if lock:
+            scriptRelease('__auto/app__')  # release the lock
+        if pf.GUI:
+            pf.GUI.stopRun()
+
+    pf.debug(f"  Arguments left after execution: {argv}", pf.DEBUG.SCRIPT)
+    msg = f"Finished {appname} in {t.seconds()} seconds"
+    if pf.GUI:
+        pf.GUI.board.write(msg, color='green')
+    else:
+        print(msg)
+    return res
+
+
+def runAny(appname=None, argv=[], remember=True, refresh=False, wait=False):
+    """Run a pyFormex application or script file.
+
+    Parameters
+    ----------
+    appname: str
+        Either the name of a pyFormex application (app) or the name of a file
+        containing a pyFormex script. An app name is specified in Python
+        fotted module format (pkg.module) and the path to the package
+        should be in the configuration variable 'appsdirs'.
+        If no appname is provided, the current app/script set in the GUI
+        will be run, if it is set.
+    argv: list, optional
+        A list of arguments to be passed to the app. This argument list
+        becomes available in the script or app as the global variable _argv_.
+    remember: bool
+        If True (default), the app is set as the current app in the GUI, so
+        that the play button can be used to run it again.
+    refresh, wait: bool
+        Parameters passed to :func:`runApp`.
+
+    See Also
+    --------
+    runScript: run a pyFormex script
+    runApp: run a pyFormex application
+    """
+    if appname is None:
+        appname = pf.cfg['curfile']
+    if not appname:
+        return
+
+    if scriptInit:
+        scriptInit()
+
+    if pf.GUI and remember:
+        pf.GUI.setcurfile(appname)
+
+    if utils.is_script(appname):
+        return runScript(appname, argv)
+    else:
+        return runApp(appname, argv, refresh=refresh, wait=wait)
+
+
 def autoExport(g):
     """Autoexport globals from script/app globals.
 
-    g: dict holding the globals dict from a script/app run enviroment.
+    Parameters
+    ----------
+    g: dict
+        A dictionary holding definitions topossibly autoexport.
+        Normally this is the globals dict from a script/app run enviroment.
 
+    Notes
+    -----
     This exports some objects from the script/app runtime globals
     to the pf.PF session globals directory.
-    The default is to export all instances of class Geometry.
+    The default is to export all instances of :class:`Geometry`.
 
     This can be customized in the script/app by setting the global
-    variable `autoglobals`. If set to a value that evaluates to
-    False, no autoexport will be done. If set to True, the default
-    autoexport will be done: all instances of :class:`geometry`.
-    If set to a list of names, only the specified names will be exported.
-    Furthermore, a global variable `autoclasses` may be set
-    to a list of class names. All global instances of the specified classes
+    variables ``autoglobals`` and ``autoclasses``.
+    If ``autoglobals`` evaluates to False, no autoexport will be done.
+    If set to True, the default autoexport will be done: all instances
+    of :class:`Geometry`. If set to a list of names, only the specified
+    names will be exported.
+    The global variable ``autoclasses`` may be set to a list of class
+    names and all global instances of the specified classes
     will be exported.
 
     Remember that the variables need to be globals in your script/app
-    in order to be autoexported, and that autoglobals feature needs to
-    be enabled in your configuration.
+    in order to be autoexported, and that the autoglobals feature
+    should not be disabled in your configuration (it is enabled by default).
     """
     ag = g.get('autoglobals', True)
     if ag:
@@ -285,108 +628,6 @@ def scriptRelease(id):
     pf.scriptMode = None
 
 
-def playScript(scr, name=None, filename=None, argv=[], encoding=None):
-    """Play a pyformex script scr. scr should be a valid Python text.
-
-    There is a lock to prevent multiple scripts from being executed at the
-    same time. This implies that pyFormex scripts can currently not be
-    recurrent.
-    If name is specified, set the global variable pyformex.scriptName to it
-    when the script is started.
-    If filename is specified, set the global variable __file__ to it.
-    """
-    global starttime
-    global exitrequested
-
-    # (We only allow one script executing at a time!)
-    # and scripts are non-reentrant
-    if len(pf.scriptlock) > 0:
-        print("!!Not executing because a script lock has been set: "
-              f"{pf.scriptlock}")
-        return 1
-
-    scriptLock('__auto/script__')
-    exitrequested = False
-
-    if pf.GUI:
-        pf.GUI.startRun()
-
-    # Read the script, if a file was specified
-    if not isinstance(scr, str):
-        # scr should be an open file/stream
-        if filename is None:
-            filename = scr.name
-        scr = scr.read() + '\n'
-
-    # Get the globals
-    g = Globals()
-    if filename:
-        g.update({'__file__': filename})
-    g.update({'argv': argv})
-
-    # BV: Should we continue support for this?
-    if encoding=='pye':
-        n = (len(scr)+1) // 2
-        scr = utils.mergeme(scr[:n], scr[n:])
-    elif encoding=='egg':
-        import base64
-        scr = base64.b64decode(scr)
-
-    if isinstance(scr, bytes):
-        scr = scr.decode('utf-8')
-
-    # Now we can execute the script using these collected globals
-    pf.scriptName = name
-    exitall = False
-
-    if pf.debugOn(pf.DEBUG.MEM):  # use a test to avoid evaluation of memUsed
-        memu = utils.memUsed()
-        vmsiz = utils.vmSize()
-        pf.debug(f"MemUsed = {memu}; vmSize = {vmsiz}", pf.DEBUG.MEM)
-
-    if filename is None:
-        filename = '<string>'
-
-    # Execute the code
-    # starttime = time.clock()
-    try:
-        pf.interpreter.locals.update(g)
-        pf.interpreter.runsource(scr, str(filename), 'exec')
-
-    except SystemExit:
-        print("EXIT FROM SCRIPT")
-
-    finally:
-        # honour the exit function
-        if 'atExit' in g:
-            atExit = g['atExit']
-            try:
-                atExit()
-            except Exception:
-                pf.debug('Error while calling script exit function',
-                         pf.DEBUG.SCRIPT)
-
-        if pf.cfg['autoglobals']:
-            if pf.console:
-                g = pf.console.interpreter.locals
-            autoExport(g)
-        scriptRelease('__auto/script__')  # release the lock
-        if pf.GUI:
-            pf.GUI.stopRun()
-
-    if pf.debugOn(pf.DEBUG.MEM):  # use a test to avoid evaluation of memUsed
-        pf.debug(f"MemUsed = {utils.memUsed()}; vmSize = {utils.vmSize()}",
-                 pf.DEBUG.MEM)
-        pf.debug(f"Diff MemUsed = {utils.memUsed()-memu}; "
-                 f"diff vmSize = {utils.vmSize()-vmsiz}", pf.DEBUG.MEM)
-
-    if exitall:
-        pf.debug("Calling quit() from playscript", pf.DEBUG.SCRIPT)
-        quit()
-
-    return 0
-
-
 def force_finish():
     pf.scriptlock = set()  # release all script locks (in case of an error)
 
@@ -424,190 +665,6 @@ def stopatbreakpt():
     exitrequested = True
 
 
-def runScript(fn, argv=[]):
-    """Play a formex script from file fn.
-
-    fn is the name of a file holding a pyFormex script.
-    A list of arguments can be passed. They will be available under the name
-    argv. This variable can be changed by the script and the resulting argv
-    is returned to the caller.
-    """
-    fn = Path(fn)
-    from pyformex.timer import Timer
-    t = Timer()
-    msg = f"Running script ({fn})"
-    if pf.GUI:
-        pf.GUI.scripthistory.add(str(fn))
-        pf.GUI.board.write(msg, color='red')
-    else:
-        print(msg)
-    pf.debug(f"  Executing with arguments: {argv}", pf.DEBUG.SCRIPT)
-    encoding = None
-    if fn.suffix == '.pye':
-        encoding = 'pye'
-
-    res = playScript(Path(fn).open('r'), fn, fn, argv, encoding)
-    pf.debug(f"  Arguments left after execution: {argv}", pf.DEBUG.SCRIPT)
-    msg = f"Finished script {fn} in {t.seconds()} seconds"
-    if pf.GUI:
-        pf.GUI.board.write(msg, color='red')
-    else:
-        print(msg)
-    return res
-
-
-def runApp(appname, argv=[], refresh=False, lock=True, check=True, wait=False):
-    """Run a pyFormex application.
-
-    A pyFormex application is a Python module that can be loaded in
-    pyFormex and that contains a function 'run()'. Running the application
-    is equivalent to executing this function.
-
-    Parameters:
-
-    - `appname`: name of the module in Python dot notation. The module should
-      live in a path included the the a file holding a pyFormex script.
-
-    - `argv`: list of arguments. This variable can be changed by the app
-      and the resulting argv will be returned to the caller.
-
-    Returns the exit value of the run function. A zero value is supposed
-    to mean a normal exit.
-    """
-    pf.debug(f"runApp '{appname}'", pf.DEBUG.APPS)
-    global exitrequested
-    if check:
-        while len(pf.scriptlock) > 0:
-            if wait:
-                 print(f"!!Waiting for lock {pf.scriptlock} to be released")
-                 sleep(5)
-            else:
-                 print("!!Not executing because a script lock has been set: "
-                       f"{pf.scriptlock}")
-                 return
-
-    from pyformex import apps
-    from pyformex.timer import Timer
-    t = Timer()
-    print(f"Loading application {appname} with refresh={refresh}")
-    app = apps.load(appname, refresh=refresh)
-    if app is None:
-        errmsg = "An error occurred while loading application {appname}"
-        if pf.GUI:
-            if apps._traceback and pf.cfg['showapploaderrors']:
-                print(apps._traceback)
-
-            from pyformex.gui import draw
-            fn = apps.findAppSource(appname)
-            if fn.exists():
-                errmsg += ("\n\nYou may try executing the application "
-                           "as a script,\n  or you can load the source "
-                           "file in the editor.")
-                res = draw.ask(errmsg, choices=[
-                    'Run as script', 'Load in editor', "Don't bother"])
-                if res[0] in 'RL':
-                    if res[0] == 'L':
-                        draw.editFile(fn)
-                    elif res[0] == 'R':
-                        pf.GUI.setcurfile(fn)
-                        draw.runScript(fn)
-            else:
-                errmsg += "and I can not find the application source file."
-                draw.error(errmsg)
-        else:
-            error(errmsg)
-
-        return
-
-    if hasattr(app, '_opengl2') and not app._opengl2:
-        pf.warning("This Example can not yet be run under the pyFormex "
-                   "opengl2 engine.\n")
-        return
-
-    if hasattr(app, '_status') and app._status == 'unchecked':
-        pf.warning(
-            "This looks like an Example script that has been automatically "
-            "converted to the pyFormex Application model, but has not been "
-            "checked yet as to whether it is working correctly in App mode.\n"
-            "You can help here by running and rerunning the example, checking "
-            "that it works correctly, and where needed fixing it (or reporting "
-            "the failure to us). If the example runs well, you can change its "
-            "status to 'checked'")
-
-    if lock:
-        scriptLock('__auto/app__')
-    msg = f"Running application '{appname}' from {app.__file__}"
-    pf.scriptName = appname
-    if pf.GUI:
-        pf.GUI.startRun()
-        pf.GUI.apphistory.add(appname)
-        pf.GUI.board.write(msg, color='green')
-    else:
-        print(msg)
-    pf.debug(f"  Passing arguments: {argv}", pf.DEBUG.SCRIPT)
-    app._args_ = argv
-    try:
-        try:
-            res = app.run()
-        except SystemExit:
-            print("EXIT FROM APP")
-            pass
-        except Exception:
-            raise
-    finally:
-        if hasattr(app, 'atExit'):
-            app.atExit()
-        if pf.cfg['autoglobals']:
-            g = app.__dict__
-            autoExport(g)
-        if lock:
-            scriptRelease('__auto/app__')  # release the lock
-        if pf.GUI:
-            pf.GUI.stopRun()
-
-    pf.debug(f"  Arguments left after execution: {argv}", pf.DEBUG.SCRIPT)
-    msg = f"Finished {appname} in {t.seconds()} seconds"
-    if pf.GUI:
-        pf.GUI.board.write(msg, color='green')
-    else:
-        print(msg)
-    pf.debug(f"Memory: {utils.vmSize()}", pf.DEBUG.MEM)
-    return res
-
-
-def runAny(appname=None, argv=[], step=False, refresh=False, remember=True, wait=False):
-    """Run the current pyFormex application or script file.
-
-    Parameters:
-
-    - `appname`: either the name of a pyFormex application (app) or a file
-      containing a pyFormex script. An app name is specified in Python
-      module syntax (package.subpackage.module) and the path to the package
-      should be in the configured app paths.
-
-    This function does nothing if no appname/filename is passed or no current
-    script/app was set.
-    If arguments are given, they are passed to the script. If `step` is True,
-    the script is executed in step mode. The 'refresh' parameter will reload
-    the app.
-    """
-    if appname is None:
-        appname = pf.cfg['curfile']
-    if not appname:
-        return
-
-    if scriptInit:
-        scriptInit()
-
-    if pf.GUI and remember:
-        pf.GUI.setcurfile(appname)
-
-    if utils.is_script(appname):
-        return runScript(appname, argv)
-    else:
-        return runApp(appname, argv, refresh, wait=wait)
-
-
 def exit(all=False):
     """Exit from the current script or from pyformex if no script running."""
     if len(pf.scriptlock) > 0:
@@ -634,7 +691,7 @@ def quit():
 
 
 def processArgs(args):
-    """Run the application without gui.
+    """Run pyFormex scripts/apps in batch mode.
 
     Arguments are interpreted as names of script files, possibly interspersed
     with arguments for the scripts.
@@ -642,16 +699,24 @@ def processArgs(args):
     """
     res = 0
     while len(args) > 0:
+        pf.debug(f"Remaining args: {args}", pf.DEBUG.SCRIPT)
         fn = args.pop(0)
         if fn == '-c':
             # next arg is a script
             txt = args.pop(0)
-            res = playScript(txt, name='__inline__')
+        if '++' in args:
+            i = args.index('++')
+            argv = args[:i]
+            args = args[i+1:]
         else:
-            res = runAny(fn, args, remember=False)
+            argv = args
+            args = []
+        if fn == '-c':
+            res = playScript(txt, name='__inline__', argv=argv)
+        else:
+            res = runAny(fn, argv=argv, remember=False)
         if res:
             print(f"Error during execution of script/app {fn}")
-
     return res
 
 
@@ -703,20 +768,23 @@ def chdir(path, create=False):
     If path does not exist and create is True, create the path and make it the
     current directory. If create is False, raise an Error.
 
-    Parameters:
+    Parameters
+    ----------
+    path: :term:`path_like`
+        The name of a directory or file. If it is a file, the name of
+        the directory containing the file is used. If the path exists, it is
+        made the current directory. The path can be an absolute
+        or a relative pathname. A '~' character at the start of the pathname will
+        be expanded to the user's home directory.
+    create: bool.
+        If True and the specified path does not exist, it will be created and
+        made the current directory. The default (False) will do nothing if the
+        specified path does not exist.
 
-    - `path`: pathname of the directory or file. If it is a file, the name of
-      the directory holding the file is used. The path can be an absolute
-      or a relative pathname. A '~' character at the start of the pathname will
-      be expanded to the user's home directory.
-
-    - `create`: bool. If True and the specified path does not exist, it will
-      be created. The default is to do nothing if the specified path does
-      not exist.
-
-    The changed to current directory is stored in the user's preferences
+    Notes
+    -----
+    The new current directory is stored in the user's preferences file
     for persistence between pyFormex invocations.
-
     """
     path = Path(path).expanduser()
     if path.exists():
@@ -750,13 +818,18 @@ def mkdir(path, clear=False, new=False):
     Create a directory, including any needed parent directories.
     Any part of the path may already exist.
 
-    - `path`: pathname of the directory to create, either an absolute
-      or relative path. A '~' character at the start of the pathname will
-      be expanded to the user's home directory.
-    - `clear`: bool. If True, and the directory already exists, its contents
-      will be deleted.
-    - `new`: bool. If True, requires the directory to be a new one. An error
-      will be raised if the path already exists.
+    Parameters
+    ----------
+    path: :term:`path_like`
+        The pathname of the directory to create, either an absolute
+        or relative path. A '~' character at the start of the pathname will
+        be expanded to the user's home directory.
+    clear: bool.
+        If True, and the directory already exists, its contents
+        will be deleted.
+    new: bool.
+        If True, requires the directory to be a new one. An error
+        will be raised if the path already exists.
 
     The following table gives an overview of the actions for different
     combinations of the parameters:
@@ -769,18 +842,25 @@ def mkdir(path, clear=False, new=False):
     T/F      T     raise                 newly created
     ======   ====  ====================  =============
 
-    If successful, returns the tilde-expanded path of the directory.
-    Raises an exception in the following cases:
+    Returns
+    -------
+    Path
+        The tilde-expanded path of the directory, if the operation was
+        successful.
 
-    - the directory could not be created,
-    - `clear` is True, and the existing directory could not be cleared,
-    - `new` is False, `clear` is False, and the existing path is not a directory,
-    - `new` is True, and the path exists.
+    Raises
+    ------
+    OSError:
+        in the following cases:
 
+        - the directory could not be created,
+        - ``clear=True``, and the existing directory could not be cleared,
+        - ``new=False, clear=False``, and the existing path is not a directory,
+        - ``new=True``, and the path exists.
     """
     path = Path(path).expanduser()
     if new and path.exists():
-        raise RuntimeError(f"Path already exists: {path}")
+        raise OSError(f"Path already exists: {path}")
     if clear and path.exists():
         if path.is_dir():
             shutil.rmtree(str(path))
@@ -794,6 +874,7 @@ def mkdir(path, clear=False, new=False):
         except OSError:
             if not path.is_dir():
                 raise
+    return path
 
 
 def runtime():
