@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -31,14 +31,45 @@ import os
 import sys
 import re
 import operator
+import json
 from distutils.version import LooseVersion as SaneVersion
-from collections import OrderedDict
 from importlib import import_module
 
 import pyformex as pf
 from pyformex import process
 
 
+def CompareVersion(a, cmp, b):
+    """Compare versions a and b with comparator cmp
+
+    Comparisons are done after converting the values with
+    distutils.version.LooseVersion
+
+    Parameters
+    ----------
+    a, b: str
+        The two version strings to compare. Version strings can
+        be something like '3.1.7a5'.
+    cmp: str
+        The comparator to be used. For example: '>='.
+
+    Returns
+    -------
+    bool
+        The result of ``a cmp b``.
+
+    Examples
+    --------
+    >>> CompareVersion('3.2.7a5', '>=', '3.2.7')
+    True
+    >>> CompareVersion('3.2.7a5', '<', '3.2.8')
+    True
+    >>> CompareVersion('3.3', '<', '3.30')
+    True
+    """
+    return eval(f"SaneVersion({a!r}) {cmp} SaneVersion({b!r})")
+
+
 class Software():
     """Register for software versions.
 
@@ -92,7 +123,7 @@ class Software():
     ValueError: A Software with name 'foo' is already registered
     """
 
-    register = OrderedDict()
+    register = dict()
 
     def __init__(self, name):
         """Create a registered software name"""
@@ -193,12 +224,12 @@ class Software():
 
         Returns
         -------
-        OrderedDict
+        dict
             A dict with the software name as key and the detected version
             as value.
         """
-        return OrderedDict([(k, clas.register[k].version) for k in
-                            clas.register if all or clas.register[k].version])
+        return dict([(k, clas.register[k].version) for k in
+                clas.register if all or clas.register[k].version])
 
 
     @classmethod
@@ -348,7 +379,7 @@ class Module(Software):
 
     """
 
-    register = OrderedDict()
+    register = dict()
 
     def __init__(self, name, modname=None, attr=None):
         """Create a registered Python module detection rule"""
@@ -418,6 +449,7 @@ class Module(Software):
         return self.version
 
 
+Module('pyformex')
 Module('calpy')
 Module('docutils')
 Module('gl2ps', attr='GL2PS_VERSION')
@@ -428,8 +460,8 @@ Module('matplotlib')
 Module('numpy')
 Module('pil', modname='PIL')
 Module('pydicom')
-Module('pyformex')
 Module('pyopengl', modname='OpenGL')
+Module('moderngl')
 Module('pyqt4', modname='PyQt4.QtCore', attr='QT_VERSION_STR')
 Module('pyqt4gl', modname='PyQt4.QtOpenGL', attr=('PyQt4.QtCore', 'QT_VERSION_STR'))
 Module('pyqt5', modname='PyQt5.QtCore', attr='PYQT_VERSION_STR')
@@ -478,7 +510,7 @@ class External(Software):
     >>> External.print_all()
     """
 
-    register = OrderedDict()
+    register = dict()
 
     def __init__(self, name, command, regex):
         """Create a registered external executable detection rule"""
@@ -531,6 +563,7 @@ class External(Software):
         return self.version
 
 
+External('python', 'python3 --version', r'Python (\S+)')
 External('admesh', 'admesh --version', r'ADMesh - version (\S+)')
 External('calculix', "ccx -v|tr '\n' ' '", r'[\n]*.*ersion (\S+)')
 External('calix', 'calix --version', r'CALIX-(\S+)')
@@ -544,7 +577,6 @@ External('gts-extra', 'gtsinside -h', r'Usage: (gts)')
 External('imagemagick', 'import -version', r'Version: ImageMagick (\S+)')
 External('instant-meshes', 'instant-meshes -h', r'Syntax: (instant-meshes)')
 External('postabq', 'pyformex-postabq -V', r'postabq (\S+).*')
-External('python', 'python3 --version', r'Python (\S+)')
 External('recordmydesktop', 'recordmydesktop --version', r'recordMyDesktop v(\S+)')
 External('tetgen', "bash -c 'type -p tetgen'", r'\S+(tetgen)')
 External('units', 'units --version', r'GNU Units version (\S+)')
@@ -582,20 +614,20 @@ def detectedSoftware(all=True):
     External.detect_all()
 
     system, host, release, version, arch = os.uname()
-    System = OrderedDict([
-        ('pyFormex_version', pf.__version__.split()[0]),
-        ('pyFormex_installtype', pf.installtype),
-        ('pyFormex_fullversion', pf.fullVersion()),
-        ('pyFormex_libraries', ', '.join(Libraries())),
-        ('pyFormex_shaders', ', '.join(Shaders())),
-        ('Python_version', sys.version.split()[0]),
-        ('Python_fullversion', sys.version.replace('\n', ' ')),
-        ('System', system),
-        ('Host', host),
-        ('Release', release),
-        ('Version', version),
-        ('Arch', arch),
-    ])
+    System = {
+        'pyFormex_version': pf.__version__.split()[0],
+        'pyFormex_installtype': pf.installtype,
+        'pyFormex_fullversion': pf.fullVersion(),
+        'pyFormex_libraries': ', '.join(Libraries()),
+        'pyFormex_shaders': ', '.join(Shaders()),
+        'Python_version': sys.version.split()[0],
+        'Python_fullversion': sys.version.replace('\n', ' '),
+        'System': system,
+        'Host': host,
+        'Release': release,
+        'Version': version,
+        'Arch': arch,
+    }
     if pf.GUI:
         System['Qt bindings'] = pf.gui.bindings
     soft = {
@@ -610,7 +642,7 @@ def reportSoftware(soft=None, header=None):
     from pyformex import utils
     notfound = '** Not Found **'
 
-    def format_dict(d, sort=True):
+    def format_dict(d, sort=False):
         keys = sorted(d.keys()) if sort else d
         items = [f"  {k} ({d[k] if d[k] else notfound})" for k in keys]
         return '\n'.join(items)
@@ -623,8 +655,8 @@ def reportSoftware(soft=None, header=None):
         s += utils.underlineHeader(header)
     for key, desc, sort in [
             ('System', 'Installed System', False),
-            ('Modules', 'Detected Python Modules', True),
-            ('Externals', 'Detected External Programs', True)
+            ('Modules', 'Detected Python Modules', False),
+            ('Externals', 'Detected External Programs', False)
     ]:
         s += f"\n{desc}:\n"
         s += format_dict(soft[key], sort=sort)
@@ -632,32 +664,6 @@ def reportSoftware(soft=None, header=None):
     return s
 
 
-def formatDict(d, indent=4):
-    """Format a dict in nicely formatted Python source representation.
-
-    Each (key, alue) pair is formatted on a line of the form::
-
-       key = value
-
-    If all the keys are strings containing only characters that are
-    allowed in Python variable names, the resulting text is a legal
-    Python script to define the items in the dict. It can be stored
-    on a file and executed.
-
-    This format is the storage format of the Config class.
-    """
-    s = "{\n"
-    for k, v in d.items():
-        s += "%s'%s' : " % (' '*indent, k)
-        if isinstance(v, dict):
-            s += formatDict(v, indent+4)
-        else:
-            s += "%r" % v
-        s += ",\n"
-    s += "%s}" % (' '*indent)
-    return s
-
-
 comparators = {
     '==': operator.__eq__,
     '!=': operator.__ne__,
@@ -751,7 +757,7 @@ def registerSoftware(req):
     """Register the current values of required software"""
     from pyformex import utils
     soft = detectedSoftware()
-    reg = {}
+    reg = dict()
     for k in req:
         reg[k] = utils.selectDict(soft[k], list(req[k].keys()))
     return reg
@@ -770,50 +776,58 @@ def soft2config(soft):
 def config2soft(conf):
     """Convert software collection from config"""
     from pyformex import utils
-    soft = {}
+    soft = dict()
     for k in ['System', 'Modules', 'Externals']:
         soft[k] = utils.subDict(conf, prefix=k+'/')
     return soft
 
 
-def storeSoftware(soft, fn, mode='pretty'):
-    """Store the software collection on file."""
-    if mode == 'pretty':
-        with open(fn, 'w') as fil:
-            fil.write("soft = "+formatDict(soft)+'\n')
-    elif mode == 'python':
-        with open(fn, 'w') as fil:
-            fil.write("soft=%r\n" % soft)
-    elif mode == 'config':
-        conf = soft2config(soft)
-        conf.write(fn)
-    elif mode == 'pickle':
-        import pickle
-        print(("PICKLING", soft))
-        pickle.dump(soft, open(fn, 'w'))
+def formatDict(d, indent=2, sort_keys=False, mode='json'):
+    """Format a possibly nested dict
+
+    >>> d = {'a':0, 'd':{'y':'s', 'x':'t'}, 'b':1}
+    >>> print(formatDict(d))
+    {
+      "a": 0,
+      "d": {
+        "y": "s",
+        "x": "t"
+      },
+      "b": 1
+    }
+    >>> print(formatDict(d, mode='python'))
+    {'a': 0, 'd': {'y': 's', 'x': 't'}, 'b': 1}
+    """
+    if mode == 'json':
+        import json
+        return json.dumps(d, indent=indent, sort_keys=False)
+    else:
+        return f"{d!r}"
 
 
-def readSoftware(fn, mode='python'):
+def storeSoftware(soft, fn, mode='json', indent=2):
+    """Store the software collection on file.
+
+    The collection is by default stored in JSON format.
+    """
+    with open(fn, 'w') as fil:
+        fil.write(formatDict(soft, indent=indent, mode=mode))
+        fil.write('\n')
+
+
+def readSoftware(fn):
     """Read the software collection from file.
 
-    - `mode` = 'pretty': readable, editable
-    - `mode` = 'python': readable, editable
-    - `mode` = 'config': readable, editable
-    - `mode` = 'pickle': binary
+    Default mode is 'python' because it reads json as well as python.
+    'legacy' can be used to read old software files, though the it is
+    recommended to change the files by removing the 'soft = ' at the start.
     """
-    from pyformex import config
-    from pyformex import utils
-    soft = None
-    if mode == 'python':
-        d = {}
-        utils.execFile(fn, {}, d)
-        soft = d['soft']
-    elif mode == 'config':
-        conf = config.Config(fn)
-        soft = config2soft(conf)
-    elif mode == 'pickle':
-        import pickle
-        soft = pickle.load(open(fn, 'r'))
+    with open(fn, 'r') as fil:
+        txt = fil.read()
+        if txt.startswith('soft'):
+            # This is probably a legacy format
+            txt = txt.split('=')[1]
+        soft = eval(txt)
     return soft
 
 
@@ -827,8 +841,9 @@ if __name__ in ["_draw__", "__script__"]:
             'Python_version': '>= 3.6.0',
         },
         'Modules': {
-            'pyformex': '>= 0.9.1',
+            'pyformex': '>= 2.4',
             'matplotlib': '1.1.1',
+            'numpy': '1.11',
         },
         'Externals': {
             'admesh': '>= 0.95',
@@ -849,14 +864,12 @@ if __name__ in ["_draw__", "__script__"]:
     print("REGISTER")
     print(formatDict(reg))
 
-    storeSoftware(reg, 'checksoft.py')
-    req = readSoftware('checksoft.py')
+    storeSoftware(reg, 'checksoft.json')
+    req = readSoftware('checksoft.json')
     print('CHECK REGISTERED')
     print(formatDict(req))
 
     ok, report = checkSoftware(req, True)
     print(report)
 
-
-
 # End
