@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -66,6 +66,7 @@ poly = 'Polygon files (*.ply *.obj)'
 postproc = 'Postproc scripts (*.post.py)'
 pyformex = 'pyFormex scripts (*.py *.pye)'
 pyf = 'pyFormex projects (*.pyf)'
+python = 'Python files (*.py)'
 pzf = 'pyFormex zip files (*.pzf)'
 smesh = 'Tetgen surface mesh files (*.smesh)'
 stl = 'STL files (*.stl)'
@@ -92,7 +93,7 @@ from pyformex import process
 
 # These are here to re-export them as utils functions
 from pyformex.software import Module, External    # noqa: F401
-from pyformex.config import formatDict            # noqa: F401
+from pyformex.mydict import formatDict            # noqa: F401
 
 #_exclude_members_ = ['runCommand']
 
@@ -100,7 +101,7 @@ shuffle = random.shuffle
 
 # Some regular expressions
 RE_digits = re.compile(r'(\d+)')
-RE_filedesc = re.compile('.*\((.*)\).*')
+RE_filedesc = re.compile(r'.*\((.*)\).*')
 
 
 ######### WARNINGS ##############
@@ -211,7 +212,7 @@ def resetWarningFilters():
     #    warnings.filters = _saved_warnings
 
     pf.debug(
-        "Current warning filters: %s" % pf.cfg['warnings/filters'],
+        f"Current warning filters: {pf.cfg['warnings/filters']}",
         pf.DEBUG.WARNING
     )
     # We always add the refcfg filters, to avoid having to store them
@@ -222,7 +223,7 @@ def resetWarningFilters():
             filterWarning(*w)
         except Exception:
             pf.debug(
-                "Error while processing warning filter: %s" % w,
+                f"Error while processing warning filter: {w}",
                 pf.DEBUG.WARNING
             )
 
@@ -652,6 +653,7 @@ FileType('poly', 'Polygon files', 'ply', 'obj')
 FileType('postproc', 'Postproc scripts', 'post.py')
 FileType('pyformex', 'pyFormex scripts', 'py', 'pye')
 FileType('pyf', 'pyFormex projects', 'pyf')
+FileType('python', 'Python files', 'py')
 FileType('pzf', 'pyFormex zip files', 'pzf')
 FileType('smesh', 'Tetgen surface mesh files', 'smesh')
 FileType('stl', 'STL files', 'stl')
@@ -781,6 +783,21 @@ def fileTypesFromFilter(fdesc):
     return [e.lstrip('*').lstrip('.') for e in ext.split(' ')]
 
 
+def setFiletypeFromFilter(filename, filter):
+    """Set the extension of a filename to an accepted one for filter
+
+    """
+    #print(f"Original: {filename}")
+    # Check and force extension for single new file
+    #print(f"Selected filter: {filter}")
+    okext = fileTypesFromFilter(filter)
+    #print(f"Accepted extensions: {okext}")
+    if not ('' in okext or filename.filetype() in okext):
+        filename = filename.with_suffix('.'+okext[0])
+    #print(f"Got filename {filename}")
+    return filename
+
+
 def okURL(url):
     """Check that an URL is displayable in the browser.
 
@@ -974,6 +991,7 @@ def moduleList(package='all'):
     This is like :func:`sourceFiles`, but returns the files in a
     Python module syntax.
     """
+    exclude = [ 'examples', 'scripts', 'opengl3' ]
     files = sourceFiles(relative=True)
     directory = os.path.split(files[0])[0]
     dirlen = len(directory)
@@ -987,8 +1005,7 @@ def moduleList(package='all'):
         modules = [m for m in modules if '.' not in m]
     elif package == 'all':
         # everything except examples
-        modules = [m for m in modules if not m.startswith('examples.')
-                   and not m.startswith('scripts.')]
+        modules = [m for m in modules if m.split('.')[0] not in exclude]
     elif package == 'all+ex':
         # everything including examples
         pass
@@ -1337,8 +1354,11 @@ def slugify(text, delim='-'):
 
 if Module.has('docutils', quiet=True):
     def rst2html(text, writer='html'):
+        import warnings
         from docutils.core import publish_string
+        warnings.filterwarnings("ignore", category=DeprecationWarning)
         return publish_string(text, writer_name=writer)
+        warnings.filterwarnings("default", category=DeprecationWarning)
 else:
     def rst2html(text, writer='html'):
         return """.. note:
@@ -1883,8 +1903,20 @@ def isFile(o):
 
 
 def is_script(appname):
-    """Checks whether an application name is rather a script name"""
-    return str(appname).endswith('.py') or str(appname).endswith('.pye')
+    """Checks whether an application name is rather a script name
+
+    Parameters
+    ----------
+    appname: str
+        The name of a script file or an app.
+
+    Returns
+    -------
+    bool:
+        True if appname ends with '.py' or '.pye', or contains a '/'.
+    """
+    appname = str(appname)
+    return appname.endswith('.py') or appname.endswith('.pye') or '/' in appname
 
 
 def is_app(appname):
@@ -2067,7 +2099,7 @@ class NameSequence(object):
         prefix, number, suffix = splitDigits(name)
         if len(number) > 0:
             self.nr = int(number)
-            format = "%%0%dd" % len(number)
+            format = f"%0{len(number)}d"
         else:
             self.nr = 0
             if name:
@@ -2377,27 +2409,6 @@ def selectDictValues(d, values):
     return [k for k in d if d[k] in values]
 
 
-def dictStr(d, skipkeys=[]):
-    """Convert a dict to a string.
-
-    This is much like dict.__str__, but formats all keys as
-    strings and prints the items with the keys sorted.
-
-    This function is can be used as replacement for the __str__
-    method od dict-like classes.
-
-    A list of strings skipkeys kan be specified, to suppress the
-    printing of some special key values.
-
-    Example:
-
-    >>> dictStr({'a':0, 'b':1, 'c':2}, ['b'])
-    "{'a': 0, 'c': 2}"
-    """
-    s = ["'%s': %r" % (k, d[k]) for k in d if k not in skipkeys]
-    return '{' + ', '.join(sorted(s)) + '}'
-
-
 class DictDiff():
     """A class to compute the difference between two dictionaries
 
@@ -2541,12 +2552,6 @@ def execFile(f, *args, **kargs):
         return exec(compile(fil.read(), f, 'exec'), *args, **kargs)
 
 
-def procInfo():
-    print('module name: %s' % __name__)
-    print('parent process: %s' % os.getppid())
-    print('process id: %s' % os.getpid())
-
-
 def interrogate(item):
     """Print useful information about item."""
     info = OrderedDict()
@@ -2667,24 +2672,10 @@ def totalMemSize(o, handlers={}, verbose=False):
     return sizeof(o)
 
 
-# TODO: this is not a good way of computing memory usage
-def vmSize():
-    return 0
-    # raise RuntimeError("From utils.vmSize")
-    # return int(os.popen('ps h o vsize %s' % os.getpid()).read().strip())
-
-
 def memUsed():
     return memory_report()['MemUsed']
 
 
-def memory_used():
-    rsskb = int(re.search(r'^VmRSS:\s+(\d+) kb$',
-                          open('/proc/self/status', 'r').read(),
-                          flags=re.IGNORECASE | re.MULTILINE).group(1))
-    return rsskb
-
-
 ###########################################################################
 ####  Deprecated  #####
 
@@ -2765,5 +2756,7 @@ def fileSize(fn):
 # fileName: use: dir / (name+ext)
 # fileSuffix: use Path.filetype
 # currentScript
+# dictStr: use repr(dict)
+# procInfo, vmSize, memory_used: not useful
 
 ### End
