@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 2.4  (Thu Feb 25 13:39:20 CET 2021)
+##  This file is part of pyFormex 2.5  (Wed Mar 24 20:37:37 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2021 (C) Benedict Verhegghe (bverheg@gmail.com)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -137,7 +137,7 @@ class Varray(object):
 
     Examples
     --------
-    Create a Varray is by default printed in user-friendly format:
+    Create a Varray from a nested list:
 
     >>> Va = Varray([[0],[1,2],[0,2,4],[0,2]])
     >>> Va
@@ -252,34 +252,25 @@ class Varray(object):
 
         # If data is a Varray, just use its data
         if isinstance(data, Varray):
-            self._replace_data(data)
+            self.data = data.data
+            self.ind = data.ind
+            self.width = data.width
+            self._row = 0
             return
 
         # Allow for empty Varray
         if len(data) <= 0:
-            data = np.array([], dtype=at.Int)
+            data = []
 
-        # If data is an array, convert to list of lists
         try:
-            data = at.checkArray(data, kind='i', ndim=2)
-            data = [row[row >= 0] for row in data]
-        except Exception:
-            pass
+            data = np.array(data, dtype=at.Int)
+        except ValueError:
+            data = np.array(data, dtype=object)
 
-        # If data is a list of lists, concatenate and create index
-        try:
-            # construct row length array
-            rowlen = [len(row) for row in data]
-            ind = at.cumsum0(rowlen)
-            data = np.concatenate(data).astype(at.Int)
-        except Exception:
-            pass
-
-        # data should now be 1D array
-        # ind is also 1D array, unless initialized from inlined length data
-        try:
-            data = at.checkArray(data, kind='i', ndim=1)
+        if data.dtype.kind == 'i' and data.ndim == 1:
+            # data is a 1-dim int array
             if ind is None:
+                # It is a 1-d array with embedded length
                 # extract row lengths from data
                 i = 0
                 size = len(data)
@@ -290,15 +281,29 @@ class Varray(object):
                 # create indices and remove row lengths from data
                 ind = at.cumsum0(rowlen)
                 data = np.delete(data, ind[:-1] + np.arange(len(rowlen)))
+            else:
+                # ind holds the indices of the row starts
+                ind = at.checkArray(ind, kind='i', ndim=1)
+                if ind[0] != 0 or ind[-1] > len(data):
+                    raise ValueError(
+                        f"Invalid ind: should start with 0; end with len(data)"
+                        f"\nGot: {ind}")
+                if np.any(ind[:-1] > ind[1:]):
+                    raise ValueError(
+                        f"Invalid ind: should be a no-decreasing sequence"
+                        f"\nGot: {ind}")
+        else:
+            # A 2-d int array or a nested list was specified
+            # remove the negative elements
+            data = [ np.array(row) for row in data ]
+            data = [row[row >= 0] for row in data]
+            rowlen = [len(row) for row in data]
+            ind = at.cumsum0(rowlen)
+            data = np.concatenate(data).astype(at.Int)
 
-            ind = at.checkArray(ind, kind='i', ndim=1)
-            ind.sort()
-            if ind[0] != 0 or ind[-1] > len(data):
-                raise ValueError
-            if ind[-1] != len(data):
-                ind = np.concatenate([ind, [len(data)]])
-        except Exception:
-            raise ValueError("Invalid input data for Varray")
+        # Make sure we have the last row
+        if ind[-1] != len(data):
+            ind = np.concatenate([ind, [len(data)]])
 
         # Store the data
         self.data = data
@@ -310,16 +315,6 @@ class Varray(object):
         self._row = 0
 
 
-    def _replace_data(self, var):
-        """Replace the current data with data from another Varray"""
-        if not isinstance(var, Varray):
-            raise ValueError("Expected a Varray as argument")
-        self.data = var.data
-        self.ind = var.ind
-        self.width = var.width
-        self._row = 0
-
-
     def copy(self):
         """Return a deep copy of the Varray"""
         return Varray(self.data.copy(), self.ind.copy())
@@ -767,12 +762,12 @@ class Varray(object):
 
     def __repr__(self):
         """String representation of the Varray"""
-        return "%s(%s)" % (self.__class__.__name__, self.toList())
+        return f"{self.__class__.__name__}({self.toList()})"
 
 
     def __str__(self):
         """Nicely print the Varray"""
-        s = "%s (%s,%s)\n" % (self.__class__.__name__, self.nrows, self.width)
+        s = f"{self.__class__.__name__} ({self.nrows},{self.width})\n"
         for row in self:
             s += '  ' + row.__str__() + '\n'
         return s
